from __future__ import annotations

from typing import Any, Optional

from ....log_helper import get_logger as get_logger
from .utils import calculate_quant_cos_error as calculate_quant_cos_error
from .utils import dequant_tensor as dequant_tensor
from .utils import load_variable_data as load_variable_data
from .utils import quant_tensor as quant_tensor
from .utils import set_variable_data as set_variable_data
from .utils import stable_sigmoid as stable_sigmoid

GAMMA: Any
ZETA: float

def compute_soft_rounding(alpha_v: Any): ...
def compute_soft_rounding_np(alpha_v: Any): ...

class AdaRoundLoss:
    default_reg_param: Any = ...
    default_beta_range: Any = ...
    def __init__(self, reg_param: float = ..., default_beta_range: Any = ...) -> None: ...
    def compute_recon_loss(self, ada_quantized_output: Any, orig_output: Any): ...
    def compute_round_loss(self, alpha_v: Any, warm_start: Any, beta: Any): ...
    def compute_beta(self, max_iter: Any, cur_iter: Any, warm_start: Any): ...

class AdaRound:
    is_train: Any = ...
    num_iterations: Any = ...
    warm_start: float = ...
    weight_bits: int = ...
    offset: float = ...
    adaround_loss: Any = ...
    ori_weight_tensor: Any = ...
    scale: Any = ...
    scope: Any = ...
    quant_axis: int = ...
    weight_var_name: Any = ...
    alpha_name: Any = ...
    def __init__(
        self,
        scale: Any,
        weight_tensor: Any,
        scope: Optional[Any] = ...,
        weight_var_name: Optional[Any] = ...,
        weight_op_type: Optional[Any] = ...,
        is_train: bool = ...,
        num_iterations: int = ...,
    ) -> None: ...
    alpha_v: Any = ...
    def initialize_alpha(self, tensor: Any, scale: Any, var_name: Any) -> None: ...
    def update_final_weights(self): ...
    def get_loss(self, beta: Any, warm_start: Any, adaround_out_tensor: Any, orig_out_tensor: Any): ...
    def update_beta_warm(self, cur_iteration: Any): ...

def run_adaround(
    data_loader: Any,
    fp32_program: Any,
    fetch_list: Any,
    exe: Any,
    scope: Any,
    place: Any,
    quantized_op_pairs: Any,
    weight_op_pairs: Any,
    scale_dict: Any,
    num_iterations: int = ...,
    lr: float = ...,
    fast_mode: bool = ...,
) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...fluid.initializer import XavierInitializer as XavierInitializer

class XavierNormal(XavierInitializer):
    def __init__(
        self, fan_in: Optional[Any] = ..., fan_out: Optional[Any] = ..., name: Optional[Any] = ...
    ) -> None: ...

class XavierUniform(XavierInitializer):
    def __init__(
        self, fan_in: Optional[Any] = ..., fan_out: Optional[Any] = ..., name: Optional[Any] = ...
    ) -> None: ...



from __future__ import annotations

from typing import Any

class Event:
    kind: Any = ...
    message: Any = ...
    fatal: Any = ...
    def __init__(self, kind: str = ..., message: str = ..., fatal: bool = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .._typing import NumbericSequence, ShapeLike, Tensor
from ..fluid import layers as layers
from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.data_feeder import convert_dtype as convert_dtype
from ..fluid.dygraph.inplace_utils import (
    inplace_apis_in_dygraph_only as inplace_apis_in_dygraph_only,
)
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..fluid.layers import cast as cast
from ..fluid.layers import scatter_nd as scatter_nd
from ..fluid.layers import shard_index as shard_index
from ..fluid.layers import slice as slice
from ..fluid.layers import transpose as transpose
from ..fluid.layers import unstack as unstack
from ..fluid.layers import utils as utils
from ..framework import OpProtoHolder as OpProtoHolder
from ..framework import convert_np_dtype_to_dtype_ as convert_np_dtype_to_dtype_
from ..framework import core as core
from ..framework import dygraph_only as dygraph_only
from ..static import Variable as Variable
from ..static import device_guard as device_guard

def fill_(x: Any, value: Any): ...
def zero_(x: Any): ...
def fill_diagonal_(x: Any, value: Any, offset: int = ..., wrap: bool = ..., name: Optional[Any] = ...): ...
def fill_diagonal_tensor_(
    x: Any, y: Any, offset: int = ..., dim1: int = ..., dim2: int = ..., name: Optional[Any] = ...
): ...
def fill_diagonal_tensor(
    x: Any, y: Any, offset: int = ..., dim1: int = ..., dim2: int = ..., name: Optional[Any] = ...
): ...
def tolist(x: Any): ...
def concat(x: Any, axis: int = ..., name: Optional[Any] = ...): ...
def broadcast_tensors(input: Any, name: Optional[Any] = ...): ...
def flip(x: Any, axis: Any, name: Optional[Any] = ...): ...
def rot90(x: Any, k: int = ..., axes: Any = ..., name: Optional[Any] = ...): ...
def flatten(x: Any, start_axis: int = ..., stop_axis: int = ..., name: Optional[Any] = ...): ...
def flatten_(x: Any, start_axis: int = ..., stop_axis: int = ..., name: Optional[Any] = ...): ...
def roll(x: Any, shifts: Any, axis: Optional[Any] = ..., name: Optional[Any] = ...): ...
def stack(x: Any, axis: int = ..., name: Optional[Any] = ...): ...
def split(x: Any, num_or_sections: Any, axis: int = ..., name: Optional[Any] = ...): ...
def squeeze(x: Any, axis: Optional[Any] = ..., name: Optional[Any] = ...): ...
def squeeze_(x: Any, axis: Optional[Any] = ..., name: Optional[Any] = ...): ...
def unique_consecutive(
    x: Any,
    return_inverse: bool = ...,
    return_counts: bool = ...,
    axis: Optional[Any] = ...,
    dtype: str = ...,
    name: Optional[Any] = ...,
): ...
def unique(
    x: Any,
    return_index: bool = ...,
    return_inverse: bool = ...,
    return_counts: bool = ...,
    axis: Optional[Any] = ...,
    dtype: str = ...,
    name: Optional[Any] = ...,
): ...
def unsqueeze(x: Any, axis: Any, name: Optional[Any] = ...): ...
def unsqueeze_(x: Any, axis: Any, name: Optional[Any] = ...): ...
def gather(x: Any, index: Any, axis: Optional[Any] = ..., name: Optional[Any] = ...): ...
def unbind(input: Any, axis: int = ...): ...
def scatter(x: Any, index: Any, updates: Any, overwrite: bool = ..., name: Optional[Any] = ...): ...
def scatter_(x: Any, index: Any, updates: Any, overwrite: bool = ..., name: Optional[Any] = ...): ...
def scatter_nd_add(x: Any, index: Any, updates: Any, name: Optional[Any] = ...): ...
def chunk(x: Any, chunks: Any, axis: int = ..., name: Optional[Any] = ...): ...
def tile(x: Any, repeat_times: Any, name: Optional[Any] = ...): ...
def expand_as(x: Any, y: Any, name: Optional[Any] = ...): ...
def broadcast_to(x: Any, shape: Any, name: Optional[Any] = ...): ...
def expand(x: Any, shape: Any, name: Optional[Any] = ...): ...
def reshape(x: Any, shape: Any, name: Optional[Any] = ...): ...
def reshape_(x: Any, shape: Any, name: Optional[Any] = ...): ...
def gather_nd(x: Any, index: Any, name: Optional[Any] = ...): ...
def strided_slice(x: Any, axes: Any, starts: Any, ends: Any, strides: Any, name: Optional[Any] = ...): ...
def tensordot(x: Any, y: Any, axes: int = ..., name: Optional[Any] = ...): ...
def as_complex(x: Any, name: Optional[Any] = ...): ...
def as_real(x: Any, name: Optional[Any] = ...): ...
def repeat_interleave(x: Any, repeats: Any, axis: Optional[Any] = ..., name: Optional[Any] = ...): ...
def moveaxis(x: Any, source: Any, destination: Any, name: Optional[Any] = ...): ...
def non_negative_axis(arr: Any, axis: Any): ...
def infer_broadcast_shape(arr: Any, indices: Any, axis: Any): ...
def take_along_axis(arr: Any, indices: Any, axis: Any): ...
def put_along_axis(arr: Any, indices: Any, values: Any, axis: Any, reduce: str = ...): ...
def put_along_axis_(arr: Any, indices: Any, values: Any, axis: Any, reduce: str = ...): ...
def crop(x: Tensor, shape: ShapeLike = ..., offsets: NumbericSequence | Tensor = ..., name=Optional[str]) -> Tensor: ...



from __future__ import annotations

from typing import Any, Optional

URL: str
MD5: str

class DataType:
    NGRAM: int = ...
    SEQ: int = ...

def word_count(f: Any, word_freq: Optional[Any] = ...): ...
def build_dict(min_word_freq: int = ...): ...
def reader_creator(filename: Any, word_idx: Any, n: Any, data_type: Any): ...
def train(word_idx: Any, n: Any, data_type: Any = ...): ...
def test(word_idx: Any, n: Any, data_type: Any = ...): ...
def fetch() -> None: ...



from __future__ import annotations

from typing import Any

from paddle.utils import gast

class BasicApiTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    class_node_dict: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self): ...
    def visit_Assign(self, node: Any): ...
    def visit_Expr(self, node: Any): ...

class ToTensorTransformer(gast.NodeTransformer):
    root: Any = ...
    def __init__(self, node: Any) -> None: ...
    def transform(self): ...
    def visit_Call(self, node: Any): ...

def is_to_variable(node: Any): ...
def to_assign_node(node: Any): ...



from __future__ import annotations

# Because pyright thinks that `paddle.vision.alexnet` is a module,
# so rename `alexnet.pyi` to `_alexnet.pyi`. `_googlenet.pyi` is same.
from ._alexnet import AlexNet as AlexNet
from ._alexnet import alexnet as alexnet
from ._googlenet import GoogLeNet as GoogLeNet
from ._googlenet import googlenet as googlenet
from .densenet import DenseNet as DenseNet
from .densenet import densenet121 as densenet121
from .densenet import densenet161 as densenet161
from .densenet import densenet169 as densenet169
from .densenet import densenet201 as densenet201
from .densenet import densenet264 as densenet264
from .inceptionv3 import InceptionV3 as InceptionV3
from .inceptionv3 import inception_v3 as inception_v3
from .lenet import LeNet as LeNet
from .mobilenetv1 import MobileNetV1 as MobileNetV1
from .mobilenetv1 import mobilenet_v1 as mobilenet_v1
from .mobilenetv2 import MobileNetV2 as MobileNetV2
from .mobilenetv2 import mobilenet_v2 as mobilenet_v2
from .mobilenetv3 import MobileNetV3Large as MobileNetV3Large
from .mobilenetv3 import MobileNetV3Small as MobileNetV3Small
from .mobilenetv3 import mobilenet_v3_large as mobilenet_v3_large
from .mobilenetv3 import mobilenet_v3_small as mobilenet_v3_small
from .resnet import ResNet as ResNet
from .resnet import resnet18 as resnet18
from .resnet import resnet34 as resnet34
from .resnet import resnet50 as resnet50
from .resnet import resnet101 as resnet101
from .resnet import resnet152 as resnet152
from .resnet import resnext50_32x4d as resnext50_32x4d
from .resnet import resnext50_64x4d as resnext50_64x4d
from .resnet import resnext101_32x4d as resnext101_32x4d
from .resnet import resnext101_64x4d as resnext101_64x4d
from .resnet import resnext152_32x4d as resnext152_32x4d
from .resnet import resnext152_64x4d as resnext152_64x4d
from .resnet import wide_resnet50_2 as wide_resnet50_2
from .resnet import wide_resnet101_2 as wide_resnet101_2
from .shufflenetv2 import ShuffleNetV2 as ShuffleNetV2
from .shufflenetv2 import shufflenet_v2_swish as shufflenet_v2_swish
from .shufflenetv2 import shufflenet_v2_x0_5 as shufflenet_v2_x0_5
from .shufflenetv2 import shufflenet_v2_x0_25 as shufflenet_v2_x0_25
from .shufflenetv2 import shufflenet_v2_x0_33 as shufflenet_v2_x0_33
from .shufflenetv2 import shufflenet_v2_x1_0 as shufflenet_v2_x1_0
from .shufflenetv2 import shufflenet_v2_x1_5 as shufflenet_v2_x1_5
from .shufflenetv2 import shufflenet_v2_x2_0 as shufflenet_v2_x2_0
from .squeezenet import SqueezeNet as SqueezeNet
from .squeezenet import squeezenet1_0 as squeezenet1_0
from .squeezenet import squeezenet1_1 as squeezenet1_1
from .vgg import VGG as VGG
from .vgg import vgg11 as vgg11
from .vgg import vgg13 as vgg13
from .vgg import vgg16 as vgg16
from .vgg import vgg19 as vgg19



from __future__ import annotations

import abc
from typing import Any

class BaseQuantizer(metaclass=abc.ABCMeta):
    quant_bits: Any = ...
    abs_max_vals: Any = ...
    thresholds: Any = ...
    def __init__(self, quant_bits: int = ...) -> None: ...
    @abc.abstractmethod
    def sample_data(self, layer: Any, tensors: Any) -> Any: ...
    @abc.abstractmethod
    def cal_thresholds(self) -> Any: ...

class AbsmaxQuantizer(BaseQuantizer):
    def __init__(self, quant_bits: int = ...) -> None: ...
    abs_max_vals: Any = ...
    def sample_data(self, layer: Any, tensors: Any) -> None: ...
    thresholds: Any = ...
    def cal_thresholds(self) -> None: ...

class PerChannelAbsmaxQuantizer(BaseQuantizer):
    def __init__(self, quant_bits: int = ...) -> None: ...
    abs_max_vals: Any = ...
    def sample_data(self, layer: Any, tensors: Any) -> None: ...
    thresholds: Any = ...
    def cal_thresholds(self) -> None: ...

class BaseHistQuantizer(BaseQuantizer, metaclass=abc.ABCMeta):
    bins: Any = ...
    upsample_bins: Any = ...
    hists: Any = ...
    def __init__(self, quant_bits: int = ..., bins: int = ..., upsample_bins: int = ...) -> None: ...
    abs_max_vals: Any = ...
    def sample_data(self, layer: Any, tensors: Any) -> None: ...
    @abc.abstractmethod
    def cal_thresholds(self) -> Any: ...

class HistQuantizer(BaseHistQuantizer):
    hist_percent: Any = ...
    def __init__(
        self, quant_bits: int = ..., bins: int = ..., upsample_bins: int = ..., hist_percent: float = ...
    ) -> None: ...
    def cal_thresholds(self): ...

class KLQuantizer(BaseHistQuantizer):
    def __init__(self, quant_bits: int = ..., bins: int = ..., upsample_bins: int = ...) -> None: ...
    def cal_thresholds(self) -> None: ...

SUPPORT_ACT_QUANTIZERS: Any
SUPPORT_WT_QUANTIZERS: Any



from __future__ import annotations

from functools import partial as partial
from typing import Any, Optional

from paddle.device import get_cudnn_version as get_cudnn_version
from paddle.device import get_device as get_device
from paddle.fluid.data_feeder import convert_dtype as convert_dtype
from paddle.fluid.layers.utils import pack_sequence_as as pack_sequence_as
from paddle.nn import Layer, LayerList

def split_states(states: Any, bidirectional: bool = ..., state_components: int = ...): ...
def concat_states(states: Any, bidirectional: bool = ..., state_components: int = ...): ...

class RNNCellBase(Layer):
    shape: Any = ...
    def get_initial_states(
        self,
        batch_ref: Any,
        shape: Optional[Any] = ...,
        dtype: Optional[Any] = ...,
        init_value: float = ...,
        batch_dim_idx: int = ...,
    ): ...
    @property
    def state_shape(self) -> None: ...
    @property
    def state_dtype(self) -> None: ...

class SimpleRNNCell(RNNCellBase):
    weight_ih: Any = ...
    weight_hh: Any = ...
    bias_ih: Any = ...
    bias_hh: Any = ...
    input_size: Any = ...
    hidden_size: Any = ...
    activation: Any = ...
    def __init__(
        self,
        input_size: Any,
        hidden_size: Any,
        activation: str = ...,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, inputs: Any, states: Optional[Any] = ...): ...
    @property
    def state_shape(self): ...
    def extra_repr(self): ...

class LSTMCell(RNNCellBase):
    weight_ih: Any = ...
    weight_hh: Any = ...
    bias_ih: Any = ...
    bias_hh: Any = ...
    hidden_size: Any = ...
    input_size: Any = ...
    def __init__(
        self,
        input_size: Any,
        hidden_size: Any,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, inputs: Any, states: Optional[Any] = ...): ...
    @property
    def state_shape(self): ...
    def extra_repr(self): ...

class GRUCell(RNNCellBase):
    weight_ih: Any = ...
    weight_hh: Any = ...
    bias_ih: Any = ...
    bias_hh: Any = ...
    hidden_size: Any = ...
    input_size: Any = ...
    def __init__(
        self,
        input_size: Any,
        hidden_size: Any,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, inputs: Any, states: Optional[Any] = ...): ...
    @property
    def state_shape(self): ...
    def extra_repr(self): ...

class RNN(Layer):
    cell: Any = ...
    is_reverse: Any = ...
    time_major: Any = ...
    def __init__(self, cell: Any, is_reverse: bool = ..., time_major: bool = ...) -> None: ...
    def forward(
        self, inputs: Any, initial_states: Optional[Any] = ..., sequence_length: Optional[Any] = ..., **kwargs: Any
    ): ...

class BiRNN(Layer):
    cell_fw: Any = ...
    cell_bw: Any = ...
    time_major: Any = ...
    def __init__(self, cell_fw: Any, cell_bw: Any, time_major: bool = ...) -> None: ...
    def forward(
        self, inputs: Any, initial_states: Optional[Any] = ..., sequence_length: Optional[Any] = ..., **kwargs: Any
    ): ...

class RNNBase(LayerList):
    mode: Any = ...
    input_size: Any = ...
    hidden_size: Any = ...
    dropout: Any = ...
    num_directions: Any = ...
    time_major: Any = ...
    num_layers: Any = ...
    state_components: Any = ...
    could_use_cudnn: bool = ...
    def __init__(
        self,
        mode: Any,
        input_size: Any,
        hidden_size: Any,
        num_layers: int = ...,
        direction: str = ...,
        time_major: bool = ...,
        dropout: float = ...,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
    ) -> None: ...
    def flatten_parameters(self) -> None: ...
    def forward(self, inputs: Any, initial_states: Optional[Any] = ..., sequence_length: Optional[Any] = ...): ...
    def extra_repr(self): ...

class SimpleRNN(RNNBase):
    activation: Any = ...
    def __init__(
        self,
        input_size: Any,
        hidden_size: Any,
        num_layers: int = ...,
        direction: str = ...,
        time_major: bool = ...,
        dropout: float = ...,
        activation: str = ...,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class LSTM(RNNBase):
    def __init__(
        self,
        input_size: Any,
        hidden_size: Any,
        num_layers: int = ...,
        direction: str = ...,
        time_major: bool = ...,
        dropout: float = ...,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...

class GRU(RNNBase):
    def __init__(
        self,
        input_size: Any,
        hidden_size: Any,
        num_layers: int = ...,
        direction: str = ...,
        time_major: bool = ...,
        dropout: float = ...,
        weight_ih_attr: Optional[Any] = ...,
        weight_hh_attr: Optional[Any] = ...,
        bias_ih_attr: Optional[Any] = ...,
        bias_hh_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class Communicator:
    mode: Any = ...
    envs: Any = ...
    communicator_: Any = ...
    send_ctx_: Any = ...
    recv_ctx_: Any = ...
    def __init__(self, mode: Any, kwargs: Optional[Any] = ..., envs: Optional[Any] = ...) -> None: ...
    def init_with_ctx(
        self, send_ctx: Any, recv_ctx: Any, proto_txt: Any, unit64_hosts: Any, scope: Optional[Any] = ...
    ) -> None: ...
    def create_client_to_client_connection(
        self, pserver_timeout_ms: int = ..., pserver_connect_timeout_ms: int = ..., max_retry: int = ...
    ) -> None: ...
    def get_client_info(self): ...
    def set_clients(self, host_list: Any) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def is_running(self) -> None: ...
    def recv(self) -> None: ...
    def init_params(self, context: Any) -> None: ...
    def pull_dense(self, context: Any) -> None: ...
    def push_sparse_param(self, var_name: Any, table_id: int = ..., scope: Optional[Any] = ...) -> None: ...

class LargeScaleKV:
    scale_kv: Any = ...
    def __init__(self) -> None: ...
    def save(self, varname: Any, dirname: Any) -> None: ...
    def load(self, varname: Any, dirname: Any) -> None: ...
    def size(self, varname: Any): ...

class HeterClient:
    heter_client_: Any = ...
    def __init__(self, endpoint: Any, previous_endpoint: Any, trainer_id: Any) -> None: ...
    def stop(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class ParallelEnvArgs:
    cluster_node_ips: Any = ...
    node_ip: Any = ...
    use_paddlecloud: Any = ...
    started_port: Any = ...
    print_config: bool = ...
    selected_devices: Any = ...
    def __init__(self) -> None: ...

class MultiprocessContext:
    error_queues: Any = ...
    return_queues: Any = ...
    processes: Any = ...
    sentinels: Any = ...
    def __init__(self, processes: Any, error_queues: Any, return_queues: Any) -> None: ...
    def join(self, timeout: Optional[Any] = ...): ...

def spawn(func: Any, args: Any = ..., nprocs: int = ..., join: bool = ..., daemon: bool = ..., **options: Any): ...



from __future__ import annotations

from typing import Any

from paddle.distributed import fleet as fleet
from paddle.fluid.optimizer import Optimizer as Optimizer

registerd_op: Any
global_cnt: int
global_input_cnt: int

class AscendHelper:
    dtype2ge_map: Any = ...
    dtype2np_map: Any = ...
    dtype2paddle_inv_map: Any = ...
    def __init__(self) -> None: ...
    def dtype2ge(self, dtype: Any): ...
    def dtype2np(self, index: Any): ...

class AscendParserFactory:
    graph: Any = ...
    var2geop: Any = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...
    def create_parse(self, parser_class: Any): ...

class AscendParserBase:
    graph: Any = ...
    var2geop: Any = ...
    op: Any = ...
    ascend_helper: Any = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...
    def update_output(self, geop_list: Any, index_list: Any) -> None: ...
    def apply(self, op: Any) -> None: ...

class AddParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotSubParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotMulParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotDivParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotPowParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LessParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MaxParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MinParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LogParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SqrtParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class PowParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SquareParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SumParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LogicalNotParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MeanParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReduceSumParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MatMulParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MulParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LayerNormParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReluParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class GeluParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class TanhParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SoftmaxWithCrossEntropyParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SoftMaxParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ShapeParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class FillConstantParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class TruncatedNormalParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class GatherParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ScatterParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class CastParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class AssignParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ScaleParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SliceParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReshapeParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class TransposeParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class AccuracyParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class TopkParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LookupTableParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class StackParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class UnSqueezeParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class AllGatherParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class AllReduceParser(AscendParserBase):
    parser_name: Any = ...
    reduction: Any = ...
    def __init__(self, graph: Any, var2geop: Any, reduction: Any) -> None: ...

class AllReduceSumParser(AllReduceParser):
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class AllReduceMaxParser(AllReduceParser):
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class BroadcastParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReduceScatterParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SendParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReceiveParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class RangeParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class UniformRandomParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class EqualParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ExpandParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SqueezeParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReduceSumGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MatMulGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MulGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReluGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SoftmaxWithCrossEntropyGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotMulGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotAddGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class DotDivGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SoftmaxGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class ReshapeGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class GatherGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class TransposeGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LayerNormGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class TanhGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LogGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SqrtGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class PowGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class GeluGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class MeanGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SliceGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class LookUpTableGradParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class SGDParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...

class AdamParser(AscendParserBase):
    parser_name: str = ...
    def __init__(self, graph: Any, var2geop: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def create_tensor(dtype: Any, name: Optional[Any] = ..., persistable: bool = ...): ...
def create_parameter(
    shape: Any,
    dtype: Any,
    name: Optional[Any] = ...,
    attr: Optional[Any] = ...,
    is_bias: bool = ...,
    default_initializer: Optional[Any] = ...,
): ...
def create_global_var(
    shape: Any, value: Any, dtype: Any, persistable: bool = ..., force_cpu: bool = ..., name: Optional[Any] = ...
): ...
def cast(x: Any, dtype: Any): ...
def concat(input: Any, axis: int = ..., name: Optional[Any] = ...): ...
def tensor_array_to_tensor(input: Any, axis: int = ..., name: Optional[Any] = ..., use_stack: bool = ...): ...
def sums(input: Any, out: Optional[Any] = ...): ...
def assign(input: Any, output: Optional[Any] = ...): ...
def fill_constant(
    shape: Any, dtype: Any, value: Any, force_cpu: bool = ..., out: Optional[Any] = ..., name: Optional[Any] = ...
): ...
def fill_constant_batch_size_like(
    input: Any,
    shape: Any,
    dtype: Any,
    value: Any,
    input_dim_idx: int = ...,
    output_dim_idx: int = ...,
    force_cpu: bool = ...,
): ...
def argmin(x: Any, axis: int = ...): ...
def argmax(x: Any, axis: int = ...): ...
def argsort(input: Any, axis: int = ..., descending: bool = ..., name: Optional[Any] = ...): ...
def ones(shape: Any, dtype: Any, force_cpu: bool = ...): ...
def zeros(shape: Any, dtype: Any, force_cpu: bool = ..., name: Optional[Any] = ...): ...
def reverse(x: Any, axis: Any): ...
def has_inf(x: Any): ...
def has_nan(x: Any): ...
def isfinite(x: Any): ...
def range(start: Any, end: Any, step: Any, dtype: Any, name: Optional[Any] = ...): ...
def linspace(start: Any, stop: Any, num: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def zeros_like(x: Any, out: Optional[Any] = ...): ...
def diag(diagonal: Any): ...
def eye(
    num_rows: Any,
    num_columns: Optional[Any] = ...,
    batch_shape: Optional[Any] = ...,
    dtype: str = ...,
    name: Optional[Any] = ...,
): ...
def ones_like(x: Any, out: Optional[Any] = ...): ...
def triu(input: Any, diagonal: int = ..., name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

def fc(
    input: Any,
    size: Any,
    num_flatten_dims: int = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def embedding(
    input: Any,
    size: Any,
    is_sparse: bool = ...,
    is_distributed: bool = ...,
    padding_idx: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    dtype: str = ...,
): ...
def linear_chain_crf(input: Any, label: Any, param_attr: Optional[Any] = ..., length: Optional[Any] = ...): ...
def crf_decoding(input: Any, param_attr: Any, label: Optional[Any] = ..., length: Optional[Any] = ...): ...
def cos_sim(X: Any, Y: Any): ...
def dropout(
    x: Any,
    dropout_prob: Any,
    is_test: Optional[Any] = ...,
    seed: Optional[Any] = ...,
    name: Optional[Any] = ...,
    dropout_implementation: str = ...,
): ...
def chunk_eval(
    input: Any,
    label: Any,
    chunk_scheme: Any,
    num_chunk_types: Any,
    excluded_chunk_types: Optional[Any] = ...,
    seq_length: Optional[Any] = ...,
): ...
def softmax(input: Any, use_cudnn: bool = ..., name: Optional[Any] = ..., axis: int = ...): ...
def conv2d(
    input: Any,
    num_filters: Any,
    filter_size: Any,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    use_cudnn: bool = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
    data_format: str = ...,
): ...
def conv3d(
    input: Any,
    num_filters: Any,
    filter_size: Any,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    use_cudnn: bool = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
    data_format: str = ...,
): ...
def pool2d(
    input: Any,
    pool_size: int = ...,
    pool_type: str = ...,
    pool_stride: int = ...,
    pool_padding: int = ...,
    global_pooling: bool = ...,
    use_cudnn: bool = ...,
    ceil_mode: bool = ...,
    name: Optional[Any] = ...,
    exclusive: bool = ...,
    data_format: str = ...,
): ...
def pool3d(
    input: Any,
    pool_size: int = ...,
    pool_type: str = ...,
    pool_stride: int = ...,
    pool_padding: int = ...,
    global_pooling: bool = ...,
    use_cudnn: bool = ...,
    ceil_mode: bool = ...,
    name: Optional[Any] = ...,
    exclusive: bool = ...,
    data_format: str = ...,
): ...
def adaptive_pool2d(
    input: Any, pool_size: Any, pool_type: str = ..., require_index: bool = ..., name: Optional[Any] = ...
): ...
def adaptive_pool3d(
    input: Any, pool_size: Any, pool_type: str = ..., require_index: bool = ..., name: Optional[Any] = ...
): ...
def batch_norm(
    input: Any,
    act: Optional[Any] = ...,
    is_test: bool = ...,
    momentum: float = ...,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    data_layout: str = ...,
    in_place: bool = ...,
    name: Optional[Any] = ...,
    moving_mean_name: Optional[Any] = ...,
    moving_variance_name: Optional[Any] = ...,
    do_model_average_for_mean_and_var: bool = ...,
    use_global_stats: bool = ...,
): ...
def inplace_abn(
    input: Any,
    act: Optional[Any] = ...,
    is_test: bool = ...,
    momentum: float = ...,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    data_layout: str = ...,
    name: Optional[Any] = ...,
    moving_mean_name: Optional[Any] = ...,
    moving_variance_name: Optional[Any] = ...,
    do_model_average_for_mean_and_var: bool = ...,
    use_global_stats: bool = ...,
    act_alpha: float = ...,
): ...
def instance_norm(
    input: Any,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def data_norm(
    input: Any,
    act: Optional[Any] = ...,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    data_layout: str = ...,
    in_place: bool = ...,
    name: Optional[Any] = ...,
    moving_mean_name: Optional[Any] = ...,
    moving_variance_name: Optional[Any] = ...,
    do_model_average_for_mean_and_var: bool = ...,
    slot_dim: int = ...,
    sync_stats: bool = ...,
    summary_decay_rate: float = ...,
    enable_scale_and_shift: bool = ...,
): ...
def layer_norm(
    input: Any,
    scale: bool = ...,
    shift: bool = ...,
    begin_norm_axis: int = ...,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def group_norm(
    input: Any,
    groups: Any,
    epsilon: float = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    act: Optional[Any] = ...,
    data_layout: str = ...,
    name: Optional[Any] = ...,
): ...
def spectral_norm(weight: Any, dim: int = ..., power_iters: int = ..., eps: float = ..., name: Optional[Any] = ...): ...
def conv2d_transpose(
    input: Any,
    num_filters: Any,
    output_size: Optional[Any] = ...,
    filter_size: Optional[Any] = ...,
    padding: int = ...,
    stride: int = ...,
    dilation: int = ...,
    groups: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    use_cudnn: bool = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
    data_format: str = ...,
): ...
def conv3d_transpose(
    input: Any,
    num_filters: Any,
    output_size: Optional[Any] = ...,
    filter_size: Optional[Any] = ...,
    padding: int = ...,
    stride: int = ...,
    dilation: int = ...,
    groups: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    use_cudnn: bool = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
    data_format: str = ...,
): ...
def reduce_sum(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def reduce_mean(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def reduce_max(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def reduce_min(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def reduce_prod(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def reduce_all(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def reduce_any(input: Any, dim: Optional[Any] = ..., keep_dim: bool = ..., name: Optional[Any] = ...): ...
def split(input: Any, num_or_sections: Any, dim: int = ..., name: Optional[Any] = ...): ...
def l2_normalize(x: Any, axis: Any, epsilon: float = ..., name: Optional[Any] = ...): ...
def matmul(
    x: Any, y: Any, transpose_x: bool = ..., transpose_y: bool = ..., alpha: float = ..., name: Optional[Any] = ...
): ...
def topk(input: Any, k: Any, name: Optional[Any] = ...): ...
def ctc_greedy_decoder(
    input: Any, blank: Any, input_length: Optional[Any] = ..., padding_value: int = ..., name: Optional[Any] = ...
): ...
def transpose(x: Any, perm: Any, name: Optional[Any] = ...): ...
def im2sequence(
    input: Any,
    filter_size: int = ...,
    stride: int = ...,
    padding: int = ...,
    input_image_size: Optional[Any] = ...,
    out_stride: int = ...,
    name: Optional[Any] = ...,
): ...
def row_conv(input: Any, future_context_size: Any, param_attr: Optional[Any] = ..., act: Optional[Any] = ...): ...
def multiplex(inputs: Any, index: Any, name: Optional[Any] = ...): ...
def smooth_l1(
    x: Any, y: Any, inside_weight: Optional[Any] = ..., outside_weight: Optional[Any] = ..., sigma: Optional[Any] = ...
): ...
def one_hot(input: Any, depth: Any, allow_out_of_range: bool = ...): ...
def autoincreased_step_counter(counter_name: Optional[Any] = ..., begin: int = ..., step: int = ...): ...
def reshape(
    x: Any,
    shape: Any,
    actual_shape: Optional[Any] = ...,
    act: Optional[Any] = ...,
    inplace: bool = ...,
    name: Optional[Any] = ...,
): ...
def squeeze(input: Any, axes: Any, name: Optional[Any] = ...): ...
def unsqueeze(input: Any, axes: Any, name: Optional[Any] = ...): ...
def lod_reset(x: Any, y: Optional[Any] = ..., target_lod: Optional[Any] = ...): ...
def lod_append(x: Any, level: Any): ...
def lrn(
    input: Any,
    n: int = ...,
    k: float = ...,
    alpha: float = ...,
    beta: float = ...,
    name: Optional[Any] = ...,
    data_format: str = ...,
): ...
def pad(x: Any, paddings: Any, pad_value: float = ..., name: Optional[Any] = ...): ...
def pad_constant_like(x: Any, y: Any, pad_value: float = ..., name: Optional[Any] = ...): ...
def label_smooth(
    label: Any, prior_dist: Optional[Any] = ..., epsilon: float = ..., dtype: str = ..., name: Optional[Any] = ...
): ...
def roi_pool(
    input: Any,
    rois: Any,
    pooled_height: int = ...,
    pooled_width: int = ...,
    spatial_scale: float = ...,
    rois_num: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def roi_align(
    input: Any,
    rois: Any,
    pooled_height: int = ...,
    pooled_width: int = ...,
    spatial_scale: float = ...,
    sampling_ratio: int = ...,
    rois_num: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def dice_loss(input: Any, label: Any, epsilon: float = ..., name: Optional[Any] = ...): ...
def image_resize(
    input: Any,
    out_shape: Optional[Any] = ...,
    scale: Optional[Any] = ...,
    name: Optional[Any] = ...,
    resample: str = ...,
    actual_shape: Optional[Any] = ...,
    align_corners: bool = ...,
    align_mode: int = ...,
    data_format: str = ...,
): ...
def resize_linear(
    input: Any,
    out_shape: Optional[Any] = ...,
    scale: Optional[Any] = ...,
    name: Optional[Any] = ...,
    actual_shape: Optional[Any] = ...,
    align_corners: bool = ...,
    align_mode: int = ...,
    data_format: str = ...,
): ...
def resize_bilinear(
    input: Any,
    out_shape: Optional[Any] = ...,
    scale: Optional[Any] = ...,
    name: Optional[Any] = ...,
    actual_shape: Optional[Any] = ...,
    align_corners: bool = ...,
    align_mode: int = ...,
    data_format: str = ...,
): ...
def resize_trilinear(
    input: Any,
    out_shape: Optional[Any] = ...,
    scale: Optional[Any] = ...,
    name: Optional[Any] = ...,
    actual_shape: Optional[Any] = ...,
    align_corners: bool = ...,
    align_mode: int = ...,
    data_format: str = ...,
): ...
def resize_nearest(
    input: Any,
    out_shape: Optional[Any] = ...,
    scale: Optional[Any] = ...,
    name: Optional[Any] = ...,
    actual_shape: Optional[Any] = ...,
    align_corners: bool = ...,
    data_format: str = ...,
): ...
def image_resize_short(input: Any, out_short_len: Any, resample: str = ...): ...
def gather(input: Any, index: Any, overwrite: bool = ...): ...
def gather_nd(input: Any, index: Any, name: Optional[Any] = ...): ...
def scatter(input: Any, index: Any, updates: Any, name: Optional[Any] = ..., overwrite: bool = ...): ...
def scatter_nd_add(ref: Any, index: Any, updates: Any, name: Optional[Any] = ...): ...
def scatter_nd(index: Any, updates: Any, shape: Any, name: Optional[Any] = ...): ...
def random_crop(x: Any, shape: Any, seed: Optional[Any] = ...): ...
def log(x: Any, name: Optional[Any] = ...): ...
def relu(x: Any, name: Optional[Any] = ...): ...
def selu(x: Any, scale: Optional[Any] = ..., alpha: Optional[Any] = ..., name: Optional[Any] = ...): ...
def mean_iou(input: Any, label: Any, num_classes: Any): ...
def crop(x: Any, shape: Optional[Any] = ..., offsets: Optional[Any] = ..., name: Optional[Any] = ...): ...
def crop_tensor(x: Any, shape: Optional[Any] = ..., offsets: Optional[Any] = ..., name: Optional[Any] = ...): ...
def affine_grid(theta: Any, out_shape: Any, name: Optional[Any] = ...): ...
def pad2d(
    input: Any,
    paddings: Any = ...,
    mode: str = ...,
    pad_value: float = ...,
    data_format: str = ...,
    name: Optional[Any] = ...,
): ...
def elu(x: Any, alpha: float = ..., name: Optional[Any] = ...): ...
def relu6(x: Any, threshold: float = ..., name: Optional[Any] = ...): ...
def pow(x: Any, factor: float = ..., name: Optional[Any] = ...): ...
def stanh(x: Any, scale_a: float = ..., scale_b: float = ..., name: Optional[Any] = ...): ...
def hard_sigmoid(x: Any, slope: float = ..., offset: float = ..., name: Optional[Any] = ...): ...
def swish(x: Any, beta: float = ..., name: Optional[Any] = ...): ...
def prelu(x: Any, mode: Any, param_attr: Optional[Any] = ..., data_format: str = ..., name: Optional[Any] = ...): ...
def brelu(x: Any, t_min: float = ..., t_max: float = ..., name: Optional[Any] = ...): ...
def leaky_relu(x: Any, alpha: float = ..., name: Optional[Any] = ...): ...
def soft_relu(x: Any, threshold: float = ..., name: Optional[Any] = ...): ...
def flatten(x: Any, axis: int = ..., name: Optional[Any] = ...): ...
def stack(x: Any, axis: int = ..., name: Optional[Any] = ...): ...
def filter_by_instag(ins: Any, ins_tag: Any, filter_tag: Any, is_lod: Any, out_val_if_empty: int = ...): ...
def unstack(x: Any, axis: int = ..., num: Optional[Any] = ...): ...
def expand(x: Any, expand_times: Any, name: Optional[Any] = ...): ...
def expand_as(x: Any, target_tensor: Any, name: Optional[Any] = ...): ...
def uniform_random_batch_size_like(
    input: Any,
    shape: Any,
    dtype: str = ...,
    input_dim_idx: int = ...,
    output_dim_idx: int = ...,
    min: Any = ...,
    max: float = ...,
    seed: int = ...,
): ...
def gaussian_random(
    shape: Any, mean: float = ..., std: float = ..., seed: int = ..., dtype: str = ..., name: Optional[Any] = ...
): ...
def sampling_id(x: Any, min: float = ..., max: float = ..., seed: int = ..., dtype: str = ...): ...
def gaussian_random_batch_size_like(
    input: Any,
    shape: Any,
    input_dim_idx: int = ...,
    output_dim_idx: int = ...,
    mean: float = ...,
    std: float = ...,
    seed: int = ...,
    dtype: str = ...,
): ...
def sum(x: Any): ...
def slice(input: Any, axes: Any, starts: Any, ends: Any): ...
def strided_slice(input: Any, axes: Any, starts: Any, ends: Any, strides: Any): ...
def shape(input: Any): ...
def rank(input: Any): ...
def size(input: Any): ...
def scale(
    x: Any,
    scale: float = ...,
    bias: float = ...,
    bias_after_scale: bool = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def elementwise_add(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_div(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_sub(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_mul(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_max(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_min(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_pow(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_mod(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def elementwise_floordiv(x: Any, y: Any, axis: int = ..., act: Optional[Any] = ..., name: Optional[Any] = ...): ...
def logical_and(x: Any, y: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def logical_or(x: Any, y: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def logical_xor(x: Any, y: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def logical_not(x: Any, out: Optional[Any] = ..., name: Optional[Any] = ...): ...
def clip(x: Any, min: Any, max: Any, name: Optional[Any] = ...): ...
def clip_by_norm(x: Any, max_norm: Any, name: Optional[Any] = ...): ...
def mean(x: Any, name: Optional[Any] = ...): ...
def merge_selected_rows(x: Any, name: Optional[Any] = ...): ...
def mul(x: Any, y: Any, x_num_col_dims: int = ..., y_num_col_dims: int = ..., name: Optional[Any] = ...): ...
def maxout(x: Any, groups: Any, name: Optional[Any] = ..., axis: int = ...): ...
def space_to_depth(x: Any, blocksize: Any, name: Optional[Any] = ...): ...
def affine_channel(
    x: Any,
    scale: Optional[Any] = ...,
    bias: Optional[Any] = ...,
    data_layout: str = ...,
    name: Optional[Any] = ...,
    act: Optional[Any] = ...,
): ...
def similarity_focus(input: Any, axis: Any, indexes: Any, name: Optional[Any] = ...): ...
def hash(input: Any, hash_size: Any, num_hash: int = ..., name: Optional[Any] = ...): ...
def grid_sampler(x: Any, grid: Any, name: Optional[Any] = ...): ...
def log_loss(input: Any, label: Any, epsilon: float = ..., name: Optional[Any] = ...): ...
def add_position_encoding(input: Any, alpha: Any, beta: Any, name: Optional[Any] = ...): ...
def bilinear_tensor_product(
    x: Any,
    y: Any,
    size: Any,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
): ...
def get_tensor_from_selected_rows(x: Any, name: Optional[Any] = ...): ...
def shuffle_channel(x: Any, group: Any, name: Optional[Any] = ...): ...
def temporal_shift(
    x: Any, seg_num: Any, shift_ratio: float = ..., name: Optional[Any] = ..., data_format: str = ...
): ...

class PyFuncRegistry:
    def __init__(self, func: Any) -> None: ...
    @classmethod
    def registered_func(cls, idx: Any): ...
    @classmethod
    def registered_func_num(cls): ...
    @property
    def id(self): ...
    def __call__(self, *args: Any): ...

def py_func(
    func: Any, x: Any, out: Any, backward_func: Optional[Any] = ..., skip_vars_in_backward_input: Optional[Any] = ...
): ...
def psroi_pool(
    input: Any,
    rois: Any,
    output_channels: Any,
    spatial_scale: Any,
    pooled_height: Any,
    pooled_width: Any,
    name: Optional[Any] = ...,
): ...
def prroi_pool(
    input: Any,
    rois: Any,
    spatial_scale: float = ...,
    pooled_height: int = ...,
    pooled_width: int = ...,
    batch_roi_nums: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def pixel_shuffle(x: Any, upscale_factor: Any): ...
def fsp_matrix(x: Any, y: Any): ...
def continuous_value_model(input: Any, cvm: Any, use_cvm: bool = ...): ...
def where(condition: Any): ...
def sign(x: Any): ...
def unique(x: Any, dtype: str = ...): ...
def unique_with_counts(x: Any, dtype: str = ...): ...
def deformable_conv(
    input: Any,
    offset: Any,
    mask: Any,
    num_filters: Any,
    filter_size: Any,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: Optional[Any] = ...,
    deformable_groups: Optional[Any] = ...,
    im2col_step: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    modulated: bool = ...,
    name: Optional[Any] = ...,
): ...
def unfold(
    x: Any, kernel_sizes: Any, strides: int = ..., paddings: int = ..., dilations: int = ..., name: Optional[Any] = ...
): ...
def deformable_roi_pooling(
    input: Any,
    rois: Any,
    trans: Any,
    no_trans: bool = ...,
    spatial_scale: float = ...,
    group_size: Any = ...,
    pooled_height: int = ...,
    pooled_width: int = ...,
    part_size: Optional[Any] = ...,
    sample_per_part: int = ...,
    trans_std: float = ...,
    position_sensitive: bool = ...,
    name: Optional[Any] = ...,
): ...
def shard_index(input: Any, index_num: Any, nshards: Any, shard_id: Any, ignore_value: int = ...): ...
def hard_swish(x: Any, threshold: float = ..., scale: float = ..., offset: float = ..., name: Optional[Any] = ...): ...
def mish(x: Any, threshold: int = ..., name: Optional[Any] = ...): ...
def gather_tree(ids: Any, parents: Any): ...
def uniform_random(
    shape: Any, dtype: str = ..., min: Any = ..., max: float = ..., seed: int = ..., name: Optional[Any] = ...
): ...
def unbind(input: Any, axis: int = ...): ...



from __future__ import annotations

from typing import Any, Optional

from ...device import get_cudnn_version as get_cudnn_version
from ...device import is_compiled_with_cuda as is_compiled_with_cuda
from ...device import is_compiled_with_rocm as is_compiled_with_rocm
from ...fluid.layers import utils as utils
from .. import Layer as Layer
from ..initializer import Normal as Normal

class _ConvNd(Layer):
    output_padding: Any = ...
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        transposed: Any,
        dims: Any,
        stride: int = ...,
        padding: int = ...,
        padding_mode: str = ...,
        output_padding: int = ...,
        dilation: int = ...,
        groups: int = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ): ...
    def extra_repr(self): ...

class Conv1D(_ConvNd):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        dilation: int = ...,
        groups: int = ...,
        padding_mode: str = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, x: Any): ...

class Conv1DTranspose(_ConvNd):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        output_padding: int = ...,
        groups: int = ...,
        dilation: int = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, x: Any, output_size: Optional[Any] = ...): ...

class Conv2D(_ConvNd):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        dilation: int = ...,
        groups: int = ...,
        padding_mode: str = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, x: Any): ...

class Conv2DTranspose(_ConvNd):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        output_padding: int = ...,
        dilation: int = ...,
        groups: int = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, x: Any, output_size: Optional[Any] = ...): ...

class Conv3D(_ConvNd):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        dilation: int = ...,
        groups: int = ...,
        padding_mode: str = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, x: Any): ...

class Conv3DTranspose(_ConvNd):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        output_padding: int = ...,
        dilation: int = ...,
        groups: int = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, x: Any, output_size: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from typing_extensions import Literal

from ..._typing import Tensor
from ...tensor.math import tanh as tanh
from ...tensor.math import tanh_ as tanh_

def celu(x: Tensor, alpha: float = ..., name: Optional[str] = ...) -> Tensor: ...
def elu(x: Tensor, alpha: float = ..., name: Optional[str] = ...) -> Tensor: ...
def elu_(x: Tensor, alpha: float = ..., name: Optional[str] = ...) -> Tensor: ...
def gelu(x: Tensor, approximate: bool = ..., name: Optional[str] = ...) -> Tensor: ...
def hardshrink(x: Tensor, threshold: float = ..., name: Optional[str] = ...) -> Tensor: ...
def hardtanh(x: Tensor, min: float = ..., max: float = ..., name: Optional[str] = ...) -> Tensor: ...
def hardsigmoid(x: Tensor, slope: float = ..., offset: float = ..., name: Optional[str] = ...) -> Tensor: ...
def hardswish(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def leaky_relu(x: Tensor, negative_slope: float = ..., name: Optional[str] = ...) -> Tensor: ...
def prelu(
    x: Tensor,
    weight: Tensor,
    data_format: Literal["NC", "NCL", "NCHW", "NCDHW", "NLC", "NHWC", "NDHWC"] = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def relu(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def relu_(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def log_sigmoid(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def maxout(x: Tensor, groups: Any, axis: int = ..., name: Optional[str] = ...) -> Tensor: ...
def relu6(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def selu(x: Tensor, scale: float = ..., alpha: float = ..., name: Optional[str] = ...) -> Tensor: ...
def silu(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def softmax(x: Tensor, axis: int = ..., dtype: Optional[Any] = ..., name: Optional[str] = ...) -> Tensor: ...
def softmax_(x: Tensor, axis: int = ..., dtype: Optional[Any] = ..., name: Optional[str] = ...) -> Tensor: ...
def softplus(x: Tensor, beta: int = ..., threshold: int = ..., name: Optional[str] = ...) -> Tensor: ...
def softshrink(x: Tensor, threshold: float = ..., name: Optional[str] = ...) -> Tensor: ...
def softsign(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def swish(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def mish(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def tanhshrink(x: Tensor, name: Optional[str] = ...) -> Tensor: ...
def thresholded_relu(x: Tensor, threshold: float = ..., name: Optional[str] = ...) -> Tensor: ...
def log_softmax(x: Any, axis: int = ..., dtype: Optional[Any] = ..., name: Optional[str] = ...) -> Tensor: ...
def glu(x: Tensor, axis: int = ..., name: Optional[str] = ...) -> Tensor: ...
def gumbel_softmax(
    x: Tensor, temperature: float = ..., hard: bool = ..., axis: int = ..., name: Optional[str] = ...
) -> Tensor: ...
def sigmoid(x: Tensor, name: Optional[str] = ...) -> Tensor: ...



from __future__ import annotations

from typing import Any, Optional

class DecoupledWeightDecay:
    def __init__(self, coeff: float = ..., apply_decay_param_fun: Optional[Any] = ..., **kwargs: Any) -> None: ...
    def backward(self, **kargs: Any): ...
    def apply_optimize(self, **kargs: Any): ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...

def extend_with_decoupled_weight_decay(base_optimizer: Any): ...



from __future__ import annotations

from typing import Any, Optional

from . import core

class Generator(core.Generator):
    place: Any = ...
    def __init__(self, place: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle import nn
from paddle.autograd import EagerPyLayer

from .group_sharded_storage import GradStorage as GradStorage
from .group_sharded_utils import GroupShardedClipGrad as GroupShardedClipGrad
from .group_sharded_utils import Type as Type
from .group_sharded_utils import device_guard as device_guard

alignment: Any
align: Any
CHECK_LAYER: Any

class GroupShardedStage3(nn.Layer):
    def __init__(
        self,
        layer: Any,
        optimizer: Any,
        group: Optional[Any] = ...,
        sync_buffers: bool = ...,
        device: str = ...,
        segment_size: Any = ...,
        pertrain_sync_models: bool = ...,
        offload: bool = ...,
        sync_comm: bool = ...,
    ) -> None: ...
    def forward(self, *inputs: Any, **kwargs: Any): ...
    def set_state_dict(self, state_dict: Any, use_structured_name: bool = ...) -> None: ...
    def state_dict(
        self, destination: Optional[Any] = ..., include_sublayers: bool = ..., structured_name_prefix: str = ...
    ): ...
    def __getattr__(self, name: Any): ...
    def get_all_parameters(self, convert2cpu: bool = ...): ...

def ForwardPreHooks(
    layer: Any,
    order_tracer: Any,
    trainable_params: Any,
    param2buffer_size: Any,
    group: Any,
    sync_comm: Any,
    offload: Any,
    task_flow: Any,
) -> None: ...

class ForwardPostHooks(EagerPyLayer):
    @staticmethod
    def forward(
        ctx: Any,
        inputs: Any,
        layer: Any,
        order_tracer: Any,
        trainable_params: Any,
        param2buffer: Any,
        param2buffer_size: Any,
        rank: Any,
        group: Any,
        sync_comm: Any,
        offload: Any,
        task_flow: Any,
    ): ...
    @staticmethod
    def backward(ctx: Any, *args: Any): ...

class TaskFlow:
    full_param: Any = ...
    full_grad: Any = ...
    use_calc: Any = ...
    callback: Any = ...
    def __init__(
        self, full_param: Any = ..., full_grad: Any = ..., use_calc: Any = ..., callback: Optional[Any] = ...
    ) -> None: ...



from __future__ import annotations

from typing import Any

def sum_ranges(ranges: Any): ...
def merge_self_ranges(src_ranges: Any, is_sorted: bool = ...): ...
def merge_ranges(range_list1: Any, range_list2: Any, is_sorted: bool = ...): ...
def intersection_ranges(range_list1: Any, range_list2: Any, is_sorted: bool = ...): ...
def subtract_ranges(range_list1: Any, range_list2: Any, is_sorted: bool = ...): ...



from __future__ import annotations

import unittest
from typing import Any

class TestPostTrainingQuantization(unittest.TestCase):
    download_path: str = ...
    cache_folder: Any = ...
    root_path: Any = ...
    int8_model_path: Any = ...
    def setUp(self) -> None: ...
    def tearDown(self) -> None: ...
    def cache_unzipping(self, target_folder: Any, zip_path: Any) -> None: ...
    def download_model(self, data_url: Any, data_md5: Any, folder_name: Any): ...
    def get_batch_reader(self, data_path: Any, place: Any): ...
    def get_simple_reader(self, data_path: Any, place: Any): ...
    def run_program(self, model_path: Any, data_path: Any, infer_iterations: Any): ...
    def generate_quantized_model(
        self,
        model_path: Any,
        data_path: Any,
        algo: str = ...,
        round_type: str = ...,
        quantizable_op_type: Any = ...,
        is_full_quantize: bool = ...,
        is_use_cache_file: bool = ...,
        is_optimize_model: bool = ...,
        batch_size: int = ...,
        batch_nums: int = ...,
        onnx_format: bool = ...,
    ) -> None: ...
    def run_test(
        self,
        model_name: Any,
        model_url: Any,
        model_md5: Any,
        data_name: Any,
        data_url: Any,
        data_md5: Any,
        algo: Any,
        round_type: Any,
        quantizable_op_type: Any,
        is_full_quantize: Any,
        is_use_cache_file: Any,
        is_optimize_model: Any,
        diff_threshold: Any,
        infer_iterations: Any,
        quant_iterations: Any,
        onnx_format: bool = ...,
    ) -> None: ...

class TestPostTrainingAvgForLSTM(TestPostTrainingQuantization):
    def test_post_training_avg(self) -> None: ...

class TestPostTrainingAvgForLSTMONNXFormat(TestPostTrainingQuantization):
    def test_post_training_avg_onnx_format(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .. import core as core
from .. import framework as framework
from .. import initializer as initializer
from .. import unique_name as unique_name
from ..distribute_lookup_table import (
    find_distributed_lookup_table as find_distributed_lookup_table,
)
from ..framework import Block as Block
from ..framework import Parameter as Parameter
from ..framework import Program as Program
from ..framework import default_main_program as default_main_program
from ..framework import default_startup_program as default_startup_program
from ..framework import grad_var_name as grad_var_name
from . import collective as collective
from .details import UnionFind as UnionFind
from .details import VarsDistributed as VarsDistributed
from .details import VarStruct as VarStruct
from .details import delete_ops as delete_ops
from .details import find_op_by_output_arg as find_op_by_output_arg
from .details import wait_server_ready as wait_server_ready
from .ps_dispatcher import PSDispatcher as PSDispatcher
from .ps_dispatcher import RoundRobin as RoundRobin

LOOKUP_TABLE_TYPE: Any
LOOKUP_TABLE_GRAD_TYPE: Any
OP_NAME_SCOPE: str
CLIP_OP_NAME_SCOPE: str
OP_ROLE_VAR_ATTR_NAME: Any
RPC_OP_ROLE_ATTR_NAME: Any
op_role_attr_name: Any
OPT_OP_ROLE_ATTR_VALUE: Any
RPC_OP_ROLE_ATTR_VALUE: Any
DIST_OP_ROLE_ATTR_VALUE: Any
LR_SCHED_OP_ROLE_ATTR_VALUE: Any
PRINT_LOG: bool

class DistributedMode:
    SYNC: int = ...
    ASYNC: int = ...
    HALF_ASYNC: int = ...
    GEO: int = ...

def log(*args: Any) -> None: ...

class VarBlock:
    varname: Any = ...
    offset: Any = ...
    size: Any = ...
    def __init__(self, varname: Any, offset: Any, size: Any) -> None: ...

def same_or_split_var(p_name: Any, var_name: Any): ...
def slice_variable(var_list: Any, slice_count: Any, min_block_size: Any): ...

class DistributeTranspilerConfig:
    slice_var_up: bool = ...
    split_method: Any = ...
    min_block_size: int = ...
    enable_dc_asgd: bool = ...
    mode: str = ...
    print_log: bool = ...
    wait_port: bool = ...
    half_async: bool = ...
    completely_not_async: bool = ...
    geo_sgd_mode: bool = ...
    geo_sgd_need_push_nums: int = ...
    nccl_comm_num: int = ...
    use_hierarchical_allreduce: bool = ...
    hierarchical_allreduce_inter_nranks: int = ...
    collective_mode: Any = ...
    def __init__(self) -> None: ...
    @property
    def runtime_split_send_recv(self): ...
    @runtime_split_send_recv.setter
    def runtime_split_send_recv(self, value: Any) -> None: ...
    @property
    def sync_mode(self): ...
    @sync_mode.setter
    def sync_mode(self, value: Any) -> None: ...

class ServerRuntimeConfig:
    def __init__(self) -> None: ...

class DistributeTranspiler:
    config: Any = ...
    distributed_mode: Any = ...
    counter_var: Any = ...
    def __init__(self, config: Optional[Any] = ...) -> None: ...
    origin_program: Any = ...
    startup_program: Any = ...
    origin_startup_program: Any = ...
    trainer_num: Any = ...
    sync_mode: Any = ...
    trainer_id: Any = ...
    pserver_endpoints: Any = ...
    vars_overview: Any = ...
    table_name: Any = ...
    has_distributed_lookup_table: Any = ...
    param_name_to_grad_name: Any = ...
    grad_name_to_param_name: Any = ...
    sparse_update_ops: Any = ...
    sparse_param_to_height_sections: Any = ...
    need_delete_optimize_vars: Any = ...
    grad_name_to_send_dummy_out: Any = ...
    def transpile(
        self,
        trainer_id: Any,
        program: Optional[Any] = ...,
        pservers: str = ...,
        trainers: int = ...,
        sync_mode: bool = ...,
        startup_program: Optional[Any] = ...,
        current_endpoint: str = ...,
    ) -> None: ...
    def get_trainer_program(self, wait_port: bool = ...): ...
    param_bak_list: Any = ...
    pserver_program: Any = ...
    def get_pserver_program(self, endpoint: Any): ...
    def get_pserver_programs(self, endpoint: Any): ...
    def get_startup_program(
        self, endpoint: Any, pserver_program: Optional[Any] = ..., startup_program: Optional[Any] = ...
    ): ...



from __future__ import annotations

from typing import Any, Optional

def list_to_ordered_dict(list_obj: Any, ordered_dict: Optional[Any] = ...): ...
def get_inputs_of_program(program: Any): ...
def get_outputs_of_program(program: Any): ...
def prune_program(program: Any, start_op_idx: Any, end_op_idx: Any): ...
def split_program(program: Any, op_indices: Any): ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid import layers as layers
from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..framework import core as core
from .logic import logical_not as logical_not

def argsort(x: Any, axis: int = ..., descending: bool = ..., name: Optional[Any] = ...): ...
def argmax(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., dtype: str = ..., name: Optional[Any] = ...): ...
def argmin(x: Any, axis: Optional[Any] = ..., keepdim: bool = ..., dtype: str = ..., name: Optional[Any] = ...): ...
def index_select(x: Any, index: Any, axis: int = ..., name: Optional[Any] = ...): ...
def nonzero(x: Any, as_tuple: bool = ...): ...
def sort(x: Any, axis: int = ..., descending: bool = ..., name: Optional[Any] = ...): ...
def mode(x: Any, axis: int = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...
def where(condition: Any, x: Optional[Any] = ..., y: Optional[Any] = ..., name: Optional[Any] = ...): ...
def index_sample(x: Any, index: Any): ...
def masked_select(x: Any, mask: Any, name: Optional[Any] = ...): ...
def topk(
    x: Any, k: Any, axis: Optional[Any] = ..., largest: bool = ..., sorted: bool = ..., name: Optional[Any] = ...
): ...
def searchsorted(
    sorted_sequence: Any, values: Any, out_int32: bool = ..., right: bool = ..., name: Optional[Any] = ...
): ...
def kthvalue(x: Any, k: Any, axis: Optional[Any] = ..., keepdim: bool = ..., name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional, TypeVar

import numpy as np
from typing_extensions import Literal, Self

# Scalar

Numberic = int | float | complex | np.number[Any]

# Scalar Sequence

_T = TypeVar("_T", bound=Numberic)
_SeqLevel1 = tuple[_T, ...] | list[_T]

_TL1 = TypeVar("_TL1", bound=_SeqLevel1[Numberic])
_SeqLevel2 = tuple[_TL1, ...] | list[_TL1]

_TL2 = TypeVar("_TL2", bound=_SeqLevel2[_SeqLevel1[Numberic]])
_SeqLevel3 = tuple[_TL2, ...] | list[_TL2]

_TL3 = TypeVar("_TL3", bound=_SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]])
_SeqLevel4 = tuple[_TL3, ...] | list[_TL3]

_TL4 = TypeVar("_TL4", bound=_SeqLevel4[_SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]]])
_SeqLevel5 = tuple[_TL4, ...] | list[_TL4]

_TL5 = TypeVar("_TL5", bound=_SeqLevel5[_SeqLevel4[_SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]]]])
_SeqLevel6 = tuple[_TL5, ...] | list[_TL5]

IntSequence = _SeqLevel1[int]
NumbericSequence = _SeqLevel1[Numberic]
NestedNumbericSequence = (
    Numberic
    | _SeqLevel1[Numberic]
    | _SeqLevel2[_SeqLevel1[Numberic]]
    | _SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]]
    | _SeqLevel4[_SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]]]
    | _SeqLevel5[_SeqLevel4[_SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]]]]
    | _SeqLevel6[_SeqLevel5[_SeqLevel4[_SeqLevel3[_SeqLevel2[_SeqLevel1[Numberic]]]]]]
)

# Shape

ShapeLike = tuple[int, ...] | list[int] | Tensor

# DType

class dtype:
    def __init__(self, arg0: int) -> None: ...

uint8: dtype
int8: dtype
int16: dtype
int32: dtype
int64: dtype
float32: dtype
float64: dtype
float16: dtype
bfloat16: dtype
complex64: dtype
complex128: dtype
bool: dtype

_DTypeString = Literal[
    "uint8",
    "int8",
    "int16",
    "int32",
    "int64",
    "float32",
    "float64",
    "float16",
    "bfloat16",
    "complex64",
    "complex128",
    "bool",
]

_DTypeNumpy = (
    type[np.uint8]
    | type[np.int8]
    | type[np.int16]
    | type[np.int32]
    | type[np.int64]
    | type[np.float32]
    | type[np.float64]
    | type[np.float16]
    | type[np.complex64]
    | type[np.complex128]
    | type[np.bool_]
    | np.dtype[Any]
)

DTypeLike = Optional[dtype | _DTypeNumpy | _DTypeString]

# Tensor

class Tensor:
    shape: list[int]
    dtype: dtype
    def __add__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __radd__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __sub__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __rsub__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __mul__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __rmul__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __div__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __rdiv__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __truediv__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __rtruediv__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __pow__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def __rpow__(self, other: Self | np.ndarray[Any, Any] | Numberic) -> Tensor: ...
    def astype(self, dtype: DTypeLike) -> Tensor: ...
    def reshape(self, shape: ShapeLike, name: Optional[str] = ...) -> Tensor: ...
    def set_value(self, value: Tensor | np.ndarray[Any, Any]) -> None: ...

# Device

class Place: ...
class CPUPlace(Place): ...

class CUDAPlace(Place):
    def __init__(self, id: int) -> None: ...

class CUDAPinnedPlace(Place): ...

class NPUPlace(Place):
    def __init__(self, id: int) -> None: ...

class IPUPlace(Place): ...

class CustomPlace(Place):
    def __init__(self, name: str, id: int) -> None: ...

class MLUPlace(Place):
    def __init__(self, id: int) -> None: ...

class XPUPlace(Place):
    def __init__(self, id: int) -> None: ...

PlaceLike = (
    CPUPlace | CUDAPlace | CUDAPinnedPlace | NPUPlace | IPUPlace | CustomPlace | MLUPlace | XPUPlace | str
)  # TODO: only support the literal like "dev:id"



from __future__ import annotations

from typing import Any, Optional

def sequence_conv(
    input: Any,
    num_filters: Any,
    filter_size: int = ...,
    filter_stride: int = ...,
    padding: bool = ...,
    padding_start: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    act: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def sequence_softmax(input: Any, use_cudnn: bool = ..., name: Optional[Any] = ...): ...
def sequence_pool(input: Any, pool_type: Any, is_test: bool = ..., pad_value: float = ...): ...
def sequence_concat(input: Any, name: Optional[Any] = ...): ...
def sequence_first_step(input: Any): ...
def sequence_last_step(input: Any): ...
def sequence_slice(input: Any, offset: Any, length: Any, name: Optional[Any] = ...): ...
def sequence_expand(x: Any, y: Any, ref_level: int = ..., name: Optional[Any] = ...): ...
def sequence_expand_as(x: Any, y: Any, name: Optional[Any] = ...): ...
def sequence_pad(x: Any, pad_value: Any, maxlen: Optional[Any] = ..., name: Optional[Any] = ...): ...
def sequence_unpad(x: Any, length: Any, name: Optional[Any] = ...): ...
def sequence_reshape(input: Any, new_dim: Any): ...
def sequence_scatter(input: Any, index: Any, updates: Any, name: Optional[Any] = ...): ...
def sequence_enumerate(input: Any, win_size: Any, pad_value: int = ..., name: Optional[Any] = ...): ...
def sequence_mask(x: Any, maxlen: Optional[Any] = ..., dtype: str = ..., name: Optional[Any] = ...): ...
def sequence_reverse(x: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from ..nn import Layer

def viterbi_decode(
    potentials: Any, transition_params: Any, lengths: Any, include_bos_eos_tag: bool = ..., name: Optional[Any] = ...
): ...

class ViterbiDecoder(Layer):
    transitions: Any = ...
    include_bos_eos_tag: Any = ...
    name: Any = ...
    def __init__(self, transitions: Any, include_bos_eos_tag: bool = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, potentials: Any, lengths: Any): ...



from __future__ import annotations

import abc
from abc import ABC
from typing import Any, Optional

from paddle.fluid.framework import program_guard as program_guard

class PassContext:
    def __init__(self) -> None: ...
    def set_attr(self, key: Any, value: Any) -> None: ...
    def get_attr(self, key: Any, default: Optional[Any] = ...): ...
    @property
    def passes(self): ...

class PassType:
    UNKNOWN: int = ...
    COMM_OPT: int = ...
    CALC_OPT: int = ...
    PARALLEL_OPT: int = ...
    FUSION_OPT: int = ...

class PassBase(ABC, metaclass=abc.ABCMeta):
    name: Any = ...
    def __init__(self) -> None: ...
    def set_attr(self, key: Any, value: Any): ...
    def get_attr(self, key: Any, default: Optional[Any] = ...): ...
    def apply(self, main_programs: Any, startup_programs: Any, context: Optional[Any] = ...): ...

def register_pass(name: Any): ...
def new_pass(name: Any, pass_attrs: Any = ...): ...

class CPPPassWrapper(PassBase):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self) -> None: ...
    @property
    def cpp_attr_types(self): ...

class PassManager:
    def __init__(self, passes: Any, context: Optional[Any] = ..., auto_solve_conflict: bool = ...) -> None: ...
    def apply(self, main_programs: Any, startup_programs: Any): ...
    @property
    def context(self): ...
    @property
    def names(self): ...
    @property
    def passes(self): ...



from __future__ import annotations

from typing import Any

class Node:
    def __init__(self, id: Any, **attrs: Any) -> None: ...
    @property
    def id(self): ...
    @property
    def attrs(self): ...
    def __getitem__(self, attr_name: Any): ...
    def __setitem__(self, attr_name: Any, attr_value: Any) -> None: ...
    def __contains__(self, attr_name: Any): ...

class Edge:
    def __init__(self, src_id: Any, tgt_id: Any, **attrs: Any) -> None: ...
    @property
    def src_id(self): ...
    @property
    def tgt_id(self): ...
    @property
    def attrs(self): ...
    def __getitem__(self, attr_name: Any): ...
    def __setitem__(self, attr_name: Any, attr_value: Any) -> None: ...
    def __contains__(self, attr_name: Any): ...

class Graph:
    def __init__(self, **attrs: Any) -> None: ...
    @property
    def nodes(self): ...
    @property
    def attrs(self): ...
    @property
    def adjs(self): ...
    def add_node(self, node_id: Any, **attrs: Any) -> None: ...
    def add_edge(self, src_id: Any, tgt_id: Any, **attrs: Any) -> None: ...
    def __len__(self): ...
    def __iter__(self) -> Any: ...
    def __getitem__(self, node_id: Any): ...
    def __contains__(self, node_id: Any): ...



from __future__ import annotations

from .dygraph_sharding_optimizer import (
    DygraphShardingOptimizer as DygraphShardingOptimizer,
)
from .heter_parallel_optimizer import HeterParallelOptimizer as HeterParallelOptimizer
from .hybrid_parallel_gradscaler import (
    HybridParallelGradScaler as HybridParallelGradScaler,
)
from .hybrid_parallel_optimizer import (
    HybridParallelOptimizer as HybridParallelOptimizer,
)



from __future__ import annotations

from typing import Any

from paddle.fluid.framework import Block as Block

LEARNING_RATE_DECAY_COUNTER: str
OP_ROLE_VAR_ATTR_NAME: Any
RPC_OP_ROLE_ATTR_NAME: Any
OPT_OP_ROLE_ATTR_VALUE: Any
LR_SCHED_OP_ROLE_ATTR_VALUE: Any

def get_op_by_type(block: Any, op_type: Any): ...
def add_listen_and_serv_pass(program: Any, config: Any): ...
def add_rpc_global_flags_pass(program: Any, config: Any): ...
def add_optimizer_pass(program: Any, config: Any): ...
def large_scale_sparse_pass(program: Any, main_program: Any, config: Any, is_startup: bool = ...): ...
def get_distributed_from_listen_and_serv(program: Any, origin_program: Any): ...
def delete_unused_in_main_pass(program: Any, config: Any): ...
def delete_unused_in_startup_pass(program: Any, main_program: Any, config: Any): ...
def build_pserver_startup_program_pass(program: Any, p_main_program: Any, config: Any): ...
def add_geo_optimizer_pass(program: Any, config: Any): ...



from __future__ import annotations

from typing import Any, Optional

from .control_flow import BlockGuard

def data(
    name: Any,
    shape: Any,
    append_batch_size: bool = ...,
    dtype: str = ...,
    lod_level: int = ...,
    type: Any = ...,
    stop_gradient: bool = ...,
): ...

class BlockGuardServ(BlockGuard):
    server: Any = ...
    def __init__(self, server: Any) -> None: ...
    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any): ...

class ListenAndServ:
    helper: Any = ...
    inputs: Any = ...
    outputs: Any = ...
    endpoint: Any = ...
    fan_in: Any = ...
    optimizer_mode: Any = ...
    def __init__(self, endpoint: Any, inputs: Any, fan_in: int = ..., optimizer_mode: bool = ...) -> None: ...
    def do(self): ...
    def get_params_and_grads(self): ...
    def parent_block(self): ...
    def complete_op(self) -> None: ...

def py_reader(
    capacity: Any,
    shapes: Any,
    dtypes: Any,
    lod_levels: Optional[Any] = ...,
    name: Optional[Any] = ...,
    use_double_buffer: bool = ...,
): ...
def create_py_reader_by_data(
    capacity: Any, feed_list: Any, name: Optional[Any] = ..., use_double_buffer: bool = ...
): ...
def double_buffer(reader: Any, place: Optional[Any] = ..., name: Optional[Any] = ...): ...
def read_file(reader: Any): ...
def load(out: Any, file_path: Any, load_as_fp16: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...fluid.framework import default_main_program as default_main_program

def sparse_attention(
    query: Any,
    key: Any,
    value: Any,
    sparse_csr_offset: Any,
    sparse_csr_columns: Any,
    key_padding_mask: Optional[Any] = ...,
    attn_mask: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any, Optional

def data(name: Any, shape: Any, dtype: Optional[Any] = ..., lod_level: int = ...): ...

class InputSpec:
    shape: Any = ...
    dtype: Any = ...
    name: Any = ...
    def __init__(self, shape: Any, dtype: str = ..., name: Optional[Any] = ...) -> None: ...
    @classmethod
    def from_tensor(cls, tensor: Any, name: Optional[Any] = ...): ...
    @classmethod
    def from_numpy(cls, ndarray: Any, name: Optional[Any] = ...): ...
    def batch(self, batch_size: Any): ...
    def unbatch(self): ...
    def __hash__(self) -> Any: ...
    def __eq__(self, other: Any) -> Any: ...
    def __ne__(self, other: Any) -> Any: ...



from __future__ import annotations

from typing import Any, Optional

def normalize(img: Any, mean: Any, std: Any, data_format: str = ...): ...
def to_grayscale(img: Any, num_output_channels: int = ..., data_format: str = ...): ...
def rotate(
    img: Any,
    angle: Any,
    interpolation: str = ...,
    expand: bool = ...,
    center: Optional[Any] = ...,
    fill: Optional[Any] = ...,
    data_format: str = ...,
): ...
def vflip(img: Any, data_format: str = ...): ...
def hflip(img: Any, data_format: str = ...): ...
def crop(img: Any, top: Any, left: Any, height: Any, width: Any, data_format: str = ...): ...
def center_crop(img: Any, output_size: Any, data_format: str = ...): ...
def pad(img: Any, padding: Any, fill: int = ..., padding_mode: str = ..., data_format: str = ...): ...
def resize(img: Any, size: Any, interpolation: str = ..., data_format: str = ...): ...



from __future__ import annotations

from typing import Any, Optional

OP_NAME_SCOPE: str
CLIP_OP_NAME_SCOPE: str
STEP_COUNTER: str
LEARNING_RATE_DECAY_COUNTER: str
OP_ROLE_VAR_ATTR_NAME: Any
RPC_OP_ROLE_ATTR_NAME: Any
RPC_OP_ROLE_ATTR_VALUE: Any
op_role_attr_name: Any
LR_SCHED_OP_ROLE_ATTR_VALUE: Any
OPT_OP_ROLE_ATTR_VALUE: Any
backward: Any
DEVICE_LIST: Any
COMMUNICATE_OPS_TYPE: Any
SPARSE_OP_LIST: Any
SPARSE_OP_TYPE_DICT: Any
SPARSE_GRAD_OP_TYPE_DICT: Any
DEFAULT_DEVICE: str
DATA_NORM_NAME: Any
DATA_NORM_GRAD_NAME: Any

def logger_config(log_path: Any, logging_name: Any): ...

ps_log_root_dir: str
logger: Any

class DistributedMode:
    SYNC: int = ...
    ASYNC: int = ...
    HALF_ASYNC: int = ...
    GEO: int = ...
    FL: int = ...

class TrainerRuntimeConfig:
    mode: Any = ...
    runtime_configs: Any = ...
    def __init__(self, valid_strategy: Any) -> None: ...
    def get_communicator_flags(self): ...

def get_lr_ops(program: Any): ...
def get_optimize_ops(_program: Any): ...
def get_dist_env(): ...
def get_role_id(role_maker: Any): ...
def get_ps_endpoint(role_maker: Any): ...
def get_ps_endpoints(role_maker: Any): ...
def get_heter_worker_endpoint(role_maker: Any): ...
def get_trainer_endpoint(role_maker: Any): ...
def get_previous_stage_trainers(role_maker: Any): ...
def is_distributed_sparse_op(op: Any): ...
def get_sparse_tablename(op: Any): ...
def is_sparse_op(op: Any): ...
def get_sparse_tablenames(programs: Any, is_distributed: Any): ...
def get_trainers(role_maker: Any): ...
def get_dense_send_context(
    program: Any, send_ctx: Any, idx: Any, merged_dense_pairs: Any, trainer_id: Any, split_dense_table: bool = ...
): ...
def get_geo_trainer_send_context(context: Any): ...
def get_the_one_send_context(
    context: Any, split_dense_table: bool = ..., use_origin_program: bool = ..., ep_list: Optional[Any] = ...
): ...
def find_heter_ops(program: Any, default_device: str = ...): ...
def union_forward_gradient_op(program_block_ops_list: Any): ...
def find_block_joints(program: Any, program_block_ops_list: Any, heter_ops: Any): ...
def find_ops_list_input_output(program: Any, ops_list: Any): ...
def find_entrance_exit_private(program: Any, program_block_ops_list: Any): ...
def entrance_exit_check(program: Any, program_block_ops_list: Any, block_var_detail: Any, heter_ops: Any): ...
def delete_block_useless_exit(program: Any, program_block_ops_list: Any, block_var_detail: Any): ...
def get_communicate_var_info(program: Any, block_index: Any, entrance_var_list: Any, type: str = ...): ...
def add_vars_by_var_list(var_name_list: Any, origin_program: Any, program: Any, block: Any) -> None: ...
def get_varlist_from_op_map(var_map: Any): ...
def screen_persistables(program: Any, var_list: Any): ...
def block_append_op(program: Any, origin_program: Any, block: Any, op: Any): ...
def get_next_stage_trainers(role_maker: Any): ...
def insert_communicate_op(
    orign_program: Any,
    role_maker: Any,
    heter_block: Any,
    stage_id: Any,
    first_op_index: Any,
    block_var_detail: Any,
    device: Any,
    is_forward: bool = ...,
): ...
def get_the_one_recv_context(
    context: Any, is_dense: bool = ..., split_dense_table: bool = ..., use_origin_program: bool = ...
): ...

dtype_to_size: Any

def get_var_mem_size(var: Any): ...

class MergedVariable:
    merged_var: Any = ...
    ordered_vars: Any = ...
    offsets: Any = ...
    def __init__(self, merged: Any, ordered: Any, offsets: Any) -> None: ...

def build_var_distributed(context: Any) -> None: ...
def get_param_grads(origin_program: Any): ...
def delete_ops(block: Any, ops: Any) -> None: ...
def find_send_op(program: Any): ...
def find_op_input_output(program: Any, block: Any, op: Any): ...
def add_heter_send_op(program: Any, heter_program: Any, block: Any, block_var_detail: Any): ...
def get_vars_name_in_block(block: Any): ...
def delete_trainer_useless_var(program: Any, static_var: Any): ...
def create_backward_block(program: Any, origin_program: Any, bp_ops_list: Any, block_var_detail: Any): ...
def debug_program(file: Any, program: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid import layers as layers

def array_length(array: Any): ...
def array_read(array: Any, i: Any): ...
def array_write(x: Any, i: Any, array: Optional[Any] = ...): ...
def create_array(dtype: Any, initialized_list: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any

from paddle.fluid.data_feeder import convert_dtype as convert_dtype

from .. import core as core
from .. import framework as framework
from .. import unique_name as unique_name
from ..framework import EagerParamBase as EagerParamBase
from ..framework import ParamBase as ParamBase
from ..framework import Parameter as Parameter
from ..framework import Variable as Variable
from ..framework import convert_np_dtype_to_dtype_ as convert_np_dtype_to_dtype_
from ..framework import in_dygraph_mode as in_dygraph_mode
from .base import switch_to_static_graph as switch_to_static_graph
from .math_op_patch import monkey_patch_math_varbase as monkey_patch_math_varbase
from .parallel import scale_loss as scale_loss

class TensorHookRemoveHelper:
    def __init__(self, tensor: Any, hook_id: Any) -> None: ...
    def remove(self): ...

def monkey_patch_varbase(): ...



from __future__ import annotations

from .operators import graph_khop_sampler as graph_khop_sampler
from .operators import graph_reindex as graph_reindex
from .operators import graph_sample_neighbors as graph_sample_neighbors
from .operators import graph_send_recv as graph_send_recv
from .operators import softmax_mask_fuse as softmax_mask_fuse
from .operators import (
    softmax_mask_fuse_upper_triangle as softmax_mask_fuse_upper_triangle,
)
from .optimizer import LookAhead as LookAhead
from .optimizer import ModelAverage as ModelAverage
from .tensor import segment_max as segment_max
from .tensor import segment_mean as segment_mean
from .tensor import segment_min as segment_min
from .tensor import segment_sum as segment_sum



from __future__ import annotations

from typing import Any, Optional

def fp16_guard() -> None: ...
def cast_model_to_fp16(program: Any, amp_lists: Optional[Any] = ..., use_fp16_guard: bool = ...): ...
def cast_parameters_to_fp16(
    place: Any, program: Any, scope: Optional[Any] = ..., to_fp16_var_names: Optional[Any] = ...
) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid import core as core

def graph_reindex(
    x: Any,
    neighbors: Any,
    count: Any,
    value_buffer: Optional[Any] = ...,
    index_buffer: Optional[Any] = ...,
    flag_buffer_hashtable: bool = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any

from paddle.utils import gast

cmpop_type_to_str: Any

def cmpop_node_to_str(node: Any): ...

class LogicalTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self): ...
    def visit_UnaryOp(self, node: Any): ...
    def visit_Compare(self, node: Any): ...
    def visit_BoolOp(self, node: Any): ...



from __future__ import annotations

from collections import abc as abc
from enum import Enum
from math import inf as inf
from typing import Any

class Taskflow:
    task: Any = ...
    callback: Any = ...
    def __init__(self, task: Any, callback: Any) -> None: ...

class Type(Enum):
    fp16: Any = ...
    fp32: Any = ...

class ShardingClipGrad:
    def __init__(self, clip: Any, device: Any, group: Any) -> None: ...
    def __getattr__(self, item: Any): ...
    def __call__(self, params_grads: Any): ...

def device_guard(dev_id: int = ..., device: str = ...) -> None: ...
def ShardingScaler(scaler: Any): ...



from __future__ import annotations

from .fused_transformer import fused_feedforward as fused_feedforward
from .fused_transformer import fused_multi_head_attention as fused_multi_head_attention
from .fused_transformer import fused_multi_transformer as fused_multi_transformer



from __future__ import annotations

from .functional import adjust_brightness as adjust_brightness
from .functional import adjust_contrast as adjust_contrast
from .functional import adjust_hue as adjust_hue
from .functional import center_crop as center_crop
from .functional import crop as crop
from .functional import hflip as hflip
from .functional import normalize as normalize
from .functional import pad as pad
from .functional import resize as resize
from .functional import rotate as rotate
from .functional import to_grayscale as to_grayscale
from .functional import to_tensor as to_tensor
from .functional import vflip as vflip
from .transforms import BaseTransform as BaseTransform
from .transforms import BrightnessTransform as BrightnessTransform
from .transforms import CenterCrop as CenterCrop
from .transforms import ColorJitter as ColorJitter
from .transforms import Compose as Compose
from .transforms import ContrastTransform as ContrastTransform
from .transforms import Grayscale as Grayscale
from .transforms import HueTransform as HueTransform
from .transforms import Normalize as Normalize
from .transforms import Pad as Pad
from .transforms import RandomCrop as RandomCrop
from .transforms import RandomHorizontalFlip as RandomHorizontalFlip
from .transforms import RandomResizedCrop as RandomResizedCrop
from .transforms import RandomRotation as RandomRotation
from .transforms import RandomVerticalFlip as RandomVerticalFlip
from .transforms import Resize as Resize
from .transforms import SaturationTransform as SaturationTransform
from .transforms import ToTensor as ToTensor
from .transforms import Transpose as Transpose



from __future__ import annotations

from typing import Any

class TrainerDesc:
    proto_desc: Any = ...
    def __init__(self) -> None: ...

class MultiTrainer(TrainerDesc):
    def __init__(self) -> None: ...

class DistMultiTrainer(TrainerDesc):
    def __init__(self) -> None: ...

class HeterXpuTrainer(TrainerDesc):
    def __init__(self) -> None: ...

class PSGPUTrainer(TrainerDesc):
    def __init__(self) -> None: ...

class HeterPipelineTrainer(TrainerDesc):
    def __init__(self) -> None: ...

class PipelineTrainer(TrainerDesc):
    def __init__(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class QuantInt8MkldnnPass:
    def __init__(self, _scope: Optional[Any] = ..., _place: Optional[Any] = ...) -> None: ...
    def apply(self, graph: Any): ...



from __future__ import annotations

from typing import Any

LOOKUP_TABLE_TYPE: str

def find_distributed_lookup_table_inputs(program: Any, table_name: Any): ...
def find_distributed_lookup_table_outputs(program: Any, table_name: Any): ...
def find_distributed_lookup_table(program: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

DATA_URL: str
DATA_MD5: str
TOTAL_EN_WORDS: int
TOTAL_DE_WORDS: int
START_MARK: str
END_MARK: str
UNK_MARK: str

class WMT16(Dataset):
    mode: Any = ...
    data_file: Any = ...
    lang: Any = ...
    src_dict_size: Any = ...
    trg_dict_size: Any = ...
    src_dict: Any = ...
    trg_dict: Any = ...
    data: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        mode: str = ...,
        src_dict_size: int = ...,
        trg_dict_size: int = ...,
        lang: str = ...,
        download: bool = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def get_dict(self, lang: Any, reverse: bool = ...): ...



from __future__ import annotations

import enum
from typing import Any

class Type(enum.Enum):
    BIJECTION = ...
    INJECTION = ...
    SURJECTION = ...
    OTHER = ...
    @classmethod
    def is_injective(cls, _type: Any): ...

class Transform:
    def __init__(self) -> None: ...
    def __call__(self, input: Any): ...
    def forward(self, x: Any): ...
    def inverse(self, y: Any): ...
    def forward_log_det_jacobian(self, x: Any): ...
    def inverse_log_det_jacobian(self, y: Any): ...
    def forward_shape(self, shape: Any): ...
    def inverse_shape(self, shape: Any): ...

class AbsTransform(Transform): ...

class AffineTransform(Transform):
    def __init__(self, loc: Any, scale: Any) -> None: ...
    @property
    def loc(self): ...
    @property
    def scale(self): ...

class ChainTransform(Transform):
    transforms: Any = ...
    def __init__(self, transforms: Any) -> None: ...

class ExpTransform(Transform):
    def __init__(self) -> None: ...

class IndependentTransform(Transform):
    def __init__(self, base: Any, reinterpreted_batch_rank: Any) -> None: ...

class PowerTransform(Transform):
    def __init__(self, power: Any) -> None: ...
    @property
    def power(self): ...

class ReshapeTransform(Transform):
    def __init__(self, in_event_shape: Any, out_event_shape: Any) -> None: ...
    @property
    def in_event_shape(self): ...
    @property
    def out_event_shape(self): ...

class SigmoidTransform(Transform): ...
class SoftmaxTransform(Transform): ...

class StackTransform(Transform):
    def __init__(self, transforms: Any, axis: int = ...) -> None: ...
    @property
    def transforms(self): ...
    @property
    def axis(self): ...

class StickBreakingTransform(Transform): ...
class TanhTransform(Transform): ...



from __future__ import annotations

from typing import Any, Optional

from typing_extensions import Literal

from ... import Tensor, nn

def create_activation_layer(act: Any) -> Optional[type[nn.ReLU] | type[nn.Swish]]: ...
def channel_shuffle(x: Tensor, groups: int) -> Tensor: ...

class InvertedResidual(nn.Layer):
    def __init__(self, in_channels: Any, out_channels: Any, stride: Any, activation_layer: Any = ...) -> None: ...
    def forward(self, inputs: Any) -> Tensor: ...

class InvertedResidualDS(nn.Layer):
    def __init__(self, in_channels: Any, out_channels: Any, stride: Any, activation_layer: Any = ...) -> None: ...
    def forward(self, inputs: Any) -> Tensor: ...

class ShuffleNetV2(nn.Layer):
    def __init__(
        self,
        scale: float = ...,
        act: Optional[Literal["relu", "swish"]] = ...,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, inputs: Tensor) -> Tensor: ...
    __call__ = forward

def shufflenet_v2_x0_25(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...
def shufflenet_v2_x0_33(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...
def shufflenet_v2_x0_5(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...
def shufflenet_v2_x1_0(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...
def shufflenet_v2_x1_5(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...
def shufflenet_v2_x2_0(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...
def shufflenet_v2_swish(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> ShuffleNetV2: ...



from __future__ import annotations

from typing import Any

from paddle.utils import gast

class DygraphToStaticAst(gast.NodeTransformer):
    translator_logger: Any = ...
    def __init__(self) -> None: ...
    root: Any = ...
    static_analysis_visitor: Any = ...
    static_analysis_root: Any = ...
    decorate_func_name: Any = ...
    def get_static_ast(self, root: Any): ...
    def transfer_from_node_type(self, node_wrapper: Any) -> None: ...
    def visit_FunctionDef(self, node: Any): ...
    def get_module_name(self): ...



from __future__ import annotations

from typing import Any

from paddle.distributed.auto_parallel.dist_context import (
    DistributedOperatorContext as DistributedOperatorContext,
)
from paddle.fluid import unique_name as unique_name
from paddle.fluid.framework import Variable as Variable
from paddle.fluid.framework import program_guard as program_guard

from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .operators.common import BACKWARD_ONLY_DIST_OPS as BACKWARD_ONLY_DIST_OPS
from .process_group import new_process_group as new_process_group
from .utils import is_backward_op as is_backward_op
from .utils import is_forward_op as is_forward_op
from .utils import print_program_with_dist_attr as print_program_with_dist_attr
from .utils import set_dist_op_desc_original_id as set_dist_op_desc_original_id

__varname_not_in_block__: Any
__not_shape_var_type__: Any

class Partitioner:
    def __init__(self, dist_context: Any, rank_id: int = ...) -> None: ...
    def partition(self, serial_main_program: Any, serial_startup_program: Any, params_grads: Any): ...
    def partition_startup_program(self, serial_main_program: Any, serial_startup_program: Any): ...
    def partition_main_program(self, serial_main_program: Any, params_and_grads: Any): ...
    def partition_block(self, ref_block: Any, target_block: Any) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.fluid import core

class PyLayerContext:
    container: Any = ...
    def __init__(self) -> None: ...
    def save_for_backward(self, *tensors: Any) -> None: ...
    def saved_tensor(self): ...

def with_mateclass(meta: Any, *bases: Any): ...

class CPyLayer:
    @classmethod
    def apply(cls, *args: Any, **kwargs: Any): ...

class PyLayerBackward(PyLayerContext):
    def backward(self, *args: Any, **kwargs: Any): ...

class LayerMeta(type):
    def __init__(cls, name: Any, bases: Any, attrs: Any): ...

class PyLayer:
    @staticmethod
    def forward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def backward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...

class EagerPyLayerContext:
    container: Any = ...
    def save_for_backward(self, *tensors: Any) -> None: ...
    def saved_tensor(self): ...
    dirty_tensors: Any = ...
    def mark_dirty(self, *args: Any) -> None: ...
    non_differentiable: Any = ...
    def mark_non_differentiable(self, *args: Any) -> None: ...
    materialize_grads: Any = ...
    def set_materialize_grads(self, value: bool) -> Any: ...

class EagerPyLayerBackward(core.eager.PyLayer, EagerPyLayerContext):
    def backward(self, *args: Any): ...

class EagerPyLayerMeta(type):
    def __init__(cls, name: Any, bases: Any, attrs: Any): ...

class EagerPyLayer:
    @staticmethod
    def forward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def backward(ctx: Any, *args: Any) -> None: ...

def once_differentiable(backward: Any): ...



from __future__ import annotations

from typing import Any

from paddle.fluid.framework import Parameter as Parameter
from paddle.fluid.framework import Variable as Variable

from ..base.private_helper_function import wait_server_ready as wait_server_ready
from .runtime_base import RuntimeBase as RuntimeBase

def conv_indent(indent: Any): ...

PSERVER_SAVE_SUFFIX: str

def parse_table_class(varname: Any, o_main_program: Any): ...
def get_default_accessor_proto(accessor: Any, varname: Any, o_main_program: Any) -> None: ...
def check_embedding_dim(accessor: Any, varname: Any, o_main_program: Any) -> None: ...

class Accessor:
    accessor_class: str = ...
    optimizer: Any = ...
    feature_dim: int = ...
    embedding_dim: int = ...
    def __init__(self) -> None: ...
    def to_string(self, indent: Any): ...

class CommonAccessor:
    accessor_class: str = ...
    table_name: Any = ...
    entry: Any = ...
    attrs: Any = ...
    params: Any = ...
    dims: Any = ...
    trainer_num: int = ...
    sync: str = ...
    table_num: Any = ...
    table_dim: Any = ...
    initializers: Any = ...
    opt_input_map: Any = ...
    opt_attr_map: Any = ...
    opt_init_map: Any = ...
    def __init__(self) -> None: ...
    def define_optimize_map(self) -> None: ...
    def parse_entry(self, varname: Any, o_main_program: Any) -> None: ...
    def get_shard(self, total_dim: Any, shard_num: Any, pserver_id: Any): ...
    def get_initializer_attr(self, value_name: Any, o_startup_program: Any): ...
    def parse_by_optimizer(
        self, grad_name: Any, is_sparse: Any, size: Any, single_dim: Any, compiled_strategy: Any, adam_d2sum: Any
    ) -> None: ...
    def to_string(self, indent: Any): ...

class Tensor:
    main_program_id: Any = ...
    startup_program_id: Any = ...
    feed_var_name: Any = ...
    fetch_var_name: Any = ...
    tensor_table_class: bool = ...
    def __init__(self) -> None: ...
    def to_string(self, indent: Any): ...

class Table:
    id: int = ...
    table_class: Any = ...
    shard_num: int = ...
    type: Any = ...
    accessor: Any = ...
    common: Any = ...
    tensor: Any = ...
    accessor_proto: Any = ...
    def __init__(self) -> None: ...
    def to_string(self, indent: Any): ...

class Service:
    server_class: str = ...
    client_class: str = ...
    service_class: str = ...
    start_server_port: int = ...
    server_thread_num: int = ...
    def __init__(self) -> None: ...
    def to_string(self, indent: Any): ...

class DownpourServer:
    service: Any = ...
    tables: Any = ...
    def __init__(self) -> None: ...
    def set_service_param(self, service: Any) -> None: ...
    def append_tables(self, table: Any) -> None: ...
    def to_string(self, indent: Any): ...

class Server:
    servers: Any = ...
    def __init__(self) -> None: ...
    def add_server(self, server: Any) -> None: ...

class DownpourWorker:
    tables: Any = ...
    def __init__(self) -> None: ...
    def append_tables(self, table: Any) -> None: ...
    def to_string(self, indent: Any): ...

class Worker:
    workers: Any = ...
    def __init__(self) -> None: ...
    def add_worker(self, worker: Any) -> None: ...

class fsClient:
    proto: Any = ...
    uri: Any = ...
    user: Any = ...
    passwd: Any = ...
    hadoop_bin: Any = ...
    def __init__(self, proto: Any) -> None: ...
    def to_string(self): ...

class TheOnePSRuntime(RuntimeBase):
    def __init__(self) -> None: ...
    def build_compiled_startegy(self): ...
    def load_model(self, path: Any, mode: Any) -> None: ...



from __future__ import annotations

from paddle.autograd.functional import Hessian as Hessian
from paddle.autograd.functional import Jacobian as Jacobian
from paddle.autograd.functional import jvp as jvp
from paddle.autograd.functional import vjp as vjp



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.framework import Operator as Operator

class HybridParallelInferenceHelper:
    ring_id: int = ...
    micro_batch_size: Any = ...
    beam_size: Any = ...
    init_comm: Any = ...
    role_maker: Any = ...
    mp_ring_id: int = ...
    global_ring_id: int = ...
    endpoints: Any = ...
    current_endpoint: Any = ...
    rank: Any = ...
    nranks: Any = ...
    num_pp: Any = ...
    num_mp: Any = ...
    global_endpoints: Any = ...
    global_rank: Any = ...
    global_nranks: Any = ...
    mp_group: Any = ...
    pp_group: Any = ...
    def __init__(
        self,
        startup_program: Any,
        main_program: Any,
        num_mp: int = ...,
        num_pp: int = ...,
        micro_batch_size: int = ...,
        beam_size: int = ...,
        init_comm: bool = ...,
        role_maker: Optional[Any] = ...,
    ) -> None: ...
    def gen_infer_program(
        self,
        sync_in_while_lastpp2firstpp_var_names: Optional[Any] = ...,
        sync_in_while_var_names: Optional[Any] = ...,
        debug: bool = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle import framework as framework
from paddle.autograd import PyLayer as PyLayer
from paddle.fluid.dygraph.layers import Layer

from .random import get_rng_state_tracker as get_rng_state_tracker

class VocabParallelEmbedding(Layer):
    model_parallel_group: Any = ...
    world_size: Any = ...
    rank: Any = ...
    origin_num_embeddings: Any = ...
    is_mp: Any = ...
    vocab_start_index: Any = ...
    weight: Any = ...
    def __init__(
        self, num_embeddings: Any, embedding_dim: Any, weight_attr: Optional[Any] = ..., name: Optional[Any] = ...
    ) -> None: ...
    def forward(self, x: Any): ...

class ColumnParallelLinear(Layer):
    model_parallel_group: Any = ...
    world_size: Any = ...
    is_mp: Any = ...
    gather_output: Any = ...
    output_size_per_partition: Any = ...
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        in_features: Any,
        out_features: Any,
        weight_attr: Optional[Any] = ...,
        has_bias: Optional[Any] = ...,
        gather_output: bool = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...

class RowParallelLinear(Layer):
    in_features: Any = ...
    out_features: Any = ...
    input_is_parallel: Any = ...
    model_parallel_group: Any = ...
    world_size: Any = ...
    rank: Any = ...
    is_mp: Any = ...
    input_size_per_partition: Any = ...
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        in_features: Any,
        out_features: Any,
        weight_attr: Optional[Any] = ...,
        has_bias: bool = ...,
        input_is_parallel: bool = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...

class ParallelCrossEntropy(Layer):
    name: Any = ...
    model_parallel_group: Any = ...
    world_size: Any = ...
    rank: Any = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def forward(self, input: Any, label: Any): ...



from __future__ import annotations

from typing import Any

from . import core as core

MP_STATUS_CHECK_INTERVAL: float
multiprocess_queue_set: Any

class CleanupFuncRegistrar:
    @classmethod
    def register(cls, function: Any, signals: Any = ...) -> None: ...



from __future__ import annotations

from paddle.reader.decorator import ComposeNotAligned as ComposeNotAligned
from paddle.reader.decorator import buffered as buffered
from paddle.reader.decorator import cache as cache
from paddle.reader.decorator import chain as chain
from paddle.reader.decorator import compose as compose
from paddle.reader.decorator import firstn as firstn
from paddle.reader.decorator import map_readers as map_readers
from paddle.reader.decorator import multiprocess_reader as multiprocess_reader
from paddle.reader.decorator import shuffle as shuffle
from paddle.reader.decorator import xmap_readers as xmap_readers



from __future__ import annotations

from typing import Any, Optional

from .base_cost import OP_COST_FACTORY as OP_COST_FACTORY
from .base_cost import CommOpCost as CommOpCost
from .base_cost import register_op_cost as register_op_cost

class AllreduceSumCost(CommOpCost):
    OP_TYPE: str = ...
    def __init__(
        self, op: Optional[Any] = ..., op_desc: Optional[Any] = ..., comm_context: Optional[Any] = ...
    ) -> None: ...
    def calc_time(self): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL: str
MD5: str
feature_names: Any

class UCIHousing(Dataset):
    mode: Any = ...
    data_file: Any = ...
    dtype: Any = ...
    def __init__(self, data_file: Optional[Any] = ..., mode: str = ..., download: bool = ...) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...



from __future__ import annotations

from typing import Any

class CostModel:
    def __init__(self) -> None: ...
    def build_program(self): ...
    def profile_measure(
        self, startup_program: Any, main_program: Any, device: str = ..., fetch_cost_list: Any = ...
    ) -> None: ...
    def static_cost_data(self): ...
    def get_static_op_time(self, op_name: Any, forward: bool = ..., dtype: str = ...): ...



from __future__ import annotations

from typing import Any, Optional

def global_scope(): ...
def scope_guard(scope: Any) -> None: ...

class FetchHandler:
    var_dict: Any = ...
    period_secs: Any = ...
    def __init__(self, var_dict: Optional[Any] = ..., period_secs: int = ...) -> None: ...
    def handler(self, res_dict: Any) -> None: ...
    @staticmethod
    def help() -> None: ...

class _StandaloneExecutor:
    def __init__(self, place: Any, main_program: Any, scope: Any) -> None: ...
    def run(self, feed_names: Any, fetch_list: Any, return_numpy: bool = ...): ...

class _ExecutorCache:
    def __init__(self, place: Any) -> None: ...

class Executor:
    place: Any = ...
    program_caches: Any = ...
    ctx_caches: Any = ...
    trainer_caches: Any = ...
    scope_caches: Any = ...
    var_caches: Any = ...
    pruned_program_caches: Any = ...
    pruned_program_scope_caches: Any = ...
    def __init__(self, place: Optional[Any] = ...) -> None: ...
    def close(self) -> None: ...
    def run(
        self,
        program: Optional[Any] = ...,
        feed: Optional[Any] = ...,
        fetch_list: Optional[Any] = ...,
        feed_var_name: str = ...,
        fetch_var_name: str = ...,
        scope: Optional[Any] = ...,
        return_numpy: bool = ...,
        use_program_cache: bool = ...,
        return_merged: bool = ...,
        use_prune: bool = ...,
    ): ...
    def infer_from_dataset(
        self,
        program: Optional[Any] = ...,
        dataset: Optional[Any] = ...,
        scope: Optional[Any] = ...,
        thread: int = ...,
        debug: bool = ...,
        fetch_list: Optional[Any] = ...,
        fetch_info: Optional[Any] = ...,
        print_period: int = ...,
        fetch_handler: Optional[Any] = ...,
    ): ...
    def start_heter_trainer(
        self,
        program: Optional[Any] = ...,
        scope: Optional[Any] = ...,
        debug: bool = ...,
        fetch_list: Optional[Any] = ...,
        fetch_info: Optional[Any] = ...,
        print_period: int = ...,
        fetch_handler: Optional[Any] = ...,
    ): ...
    def train_from_dataset(
        self,
        program: Optional[Any] = ...,
        dataset: Optional[Any] = ...,
        scope: Optional[Any] = ...,
        thread: int = ...,
        debug: bool = ...,
        fetch_list: Optional[Any] = ...,
        fetch_info: Optional[Any] = ...,
        print_period: int = ...,
        fetch_handler: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from typing import Any, Optional

class ParamAttr:
    name: Any = ...
    initializer: Any = ...
    learning_rate: Any = ...
    regularizer: Any = ...
    trainable: Any = ...
    do_model_average: Any = ...
    need_clip: Any = ...
    def __init__(
        self,
        name: Optional[Any] = ...,
        initializer: Optional[Any] = ...,
        learning_rate: float = ...,
        regularizer: Optional[Any] = ...,
        trainable: bool = ...,
        do_model_average: bool = ...,
        need_clip: bool = ...,
    ) -> None: ...

class WeightNormParamAttr(ParamAttr):
    params_with_weight_norm: Any = ...
    dim: Any = ...
    def __init__(
        self,
        dim: Optional[Any] = ...,
        name: Optional[Any] = ...,
        initializer: Optional[Any] = ...,
        learning_rate: float = ...,
        regularizer: Optional[Any] = ...,
        trainable: bool = ...,
        do_model_average: bool = ...,
        need_clip: bool = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL: str
MD5: str

class Imikolov(Dataset):
    data_type: Any = ...
    mode: Any = ...
    window_size: Any = ...
    min_word_freq: Any = ...
    data_file: Any = ...
    word_idx: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        data_type: str = ...,
        window_size: int = ...,
        mode: str = ...,
        min_word_freq: int = ...,
        download: bool = ...,
    ) -> None: ...
    def word_count(self, f: Any, word_freq: Optional[Any] = ...): ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...



from __future__ import annotations

from typing import Any

from .meta_optimizer_base import MetaOptimizerBase as MetaOptimizerBase

class FP16AllReduceOptimizer(MetaOptimizerBase):
    inner_opt: Any = ...
    meta_optimizers_white_list: Any = ...
    meta_optimizers_black_list: Any = ...
    def __init__(self, optimizer: Any) -> None: ...
    @staticmethod
    def fp16_compression(param_and_grads: Any): ...
    def apply_optimize(self, loss: Any, startup_program: Any, params_grads: Any): ...



from __future__ import annotations

import unittest
from typing import Any

def conv_net(img: Any, label: Any): ...

class TestMKLDNNTransformBasedFreezePass(unittest.TestCase):
    quantizable_op_and_inputs: Any = ...
    def setUp(self) -> None: ...
    def check_program(self, program: Any) -> None: ...
    def isinteger(self, x: Any): ...
    def build_program(self, main: Any, startup: Any, is_test: Any, seed: Any): ...
    def mkldnn_based_freeze_graph(
        self,
        use_cuda: Any,
        seed: Any,
        activation_quant_type: Any,
        weight_quant_type: str = ...,
        quant_perf: bool = ...,
        for_ci: bool = ...,
    ) -> None: ...
    def test_mkldnn_graph_cpu_static(self) -> None: ...



from __future__ import annotations

import unittest
from typing import Any

import paddle
import paddle.nn as nn
from paddle.fluid.contrib.slim.quantization import (
    QuantizationTransformPass as QuantizationTransformPass,
)
from paddle.nn.quant.quant_layers import (
    QuantizedConv2DTranspose as QuantizedConv2DTranspose,
)

class PACT(nn.Layer):
    alpha: Any = ...
    def __init__(self, init_value: int = ...) -> None: ...
    def forward(self, x: Any): ...

class CustomQAT(nn.Layer):
    u_param: Any = ...
    l_param: Any = ...
    alpha_param: Any = ...
    upper: Any = ...
    lower: Any = ...
    def __init__(self) -> None: ...
    def forward(self, x: Any): ...

class ModelForConv2dT(nn.Layer):
    features: Any = ...
    fc: Any = ...
    def __init__(self, num_classes: int = ...) -> None: ...
    def forward(self, inputs: Any): ...

class ImperativeLenet(paddle.nn.Layer):
    features: Any = ...
    fc: Any = ...
    def __init__(self, num_classes: int = ..., classifier_activation: str = ...) -> None: ...
    def forward(self, inputs: Any): ...

class TestUserDefinedActPreprocess(unittest.TestCase):
    imperative_qat: Any = ...
    def setUp(self) -> None: ...
    def func_quant_aware_training(self) -> None: ...
    def test_quant_aware_training(self) -> None: ...

class TestUserDefinedWeightPreprocess(TestUserDefinedActPreprocess):
    imperative_qat: Any = ...
    def setUp(self) -> None: ...

class TestUserDefinedActQuantize(TestUserDefinedActPreprocess):
    imperative_qat: Any = ...
    def setUp(self) -> None: ...

class TestUserDefinedWeightQuantize(TestUserDefinedActPreprocess):
    imperative_qat: Any = ...
    def setUp(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid import core as core
from ..fluid import framework as framework
from ..fluid import layers as layers
from ..fluid import unique_name as unique_name
from ..fluid.framework import Variable as Variable
from ..fluid.framework import name_scope as name_scope
from ..fluid.layer_helper import LayerHelper as LayerHelper
from .optimizer import Optimizer as Optimizer

class Momentum(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        momentum: float = ...,
        parameters: Optional[Any] = ...,
        use_nesterov: bool = ...,
        weight_decay: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        multi_precision: bool = ...,
        rescale_grad: float = ...,
        use_multi_tensor: bool = ...,
        name: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from . import amp_lists as amp_lists
from . import amp_utils as amp_utils
from . import decorator as decorator
from .amp_lists import *
from .amp_utils import *
from .decorator import *



from __future__ import annotations

import unittest
from typing import Any

def reader_creator_10(dur: Any): ...

class TestMap(unittest.TestCase):
    def test_map(self): ...

class TestBuffered(unittest.TestCase):
    def test_read(self) -> None: ...
    def test_buffering(self) -> None: ...

class TestCompose(unittest.TestCase):
    def test_compse(self) -> None: ...
    def test_compose_not_aligned(self) -> None: ...
    def test_compose_not_aligned_no_check(self) -> None: ...

class TestChain(unittest.TestCase):
    def test_chain(self) -> None: ...

class TestShuffle(unittest.TestCase):
    def test_shuffle(self) -> None: ...

class TestXmap(unittest.TestCase):
    def test_xmap(self): ...

class TestMultiProcessReader(unittest.TestCase):
    samples: Any = ...
    reader0: Any = ...
    reader1: Any = ...
    reader2: Any = ...
    def setup(self) -> None: ...
    def reader_test(self, use_pipe: Any) -> None: ...
    def test_distributed_batch_reader(self) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.utils import gast

RETURN_NO_VALUE_MAGIC_NUM: float
RETURN_NO_VALUE_VAR_NAME: str

class ReplaceReturnNoneTransformer(gast.NodeTransformer):
    root: Any = ...
    def __init__(self, root_node: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_Return(self, node: Any): ...

class ReturnAnalysisVisitor(gast.NodeVisitor):
    root: Any = ...
    function_def: Any = ...
    count_return: Any = ...
    max_return_length: Any = ...
    def __init__(self, root_node: Any) -> None: ...
    def visit_FunctionDef(self, node: Any): ...
    def visit_Return(self, node: Any) -> None: ...
    def get_func_return_count(self, func_node: Any): ...
    def get_func_max_return_length(self, func_node: Any): ...

class ReturnTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    ancestor_nodes: Any = ...
    return_value_name: Any = ...
    return_name: Any = ...
    return_no_value_name: Any = ...
    function_def: Any = ...
    pre_analysis: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def generic_visit(self, node: Any) -> None: ...
    def visit(self, node: Any): ...
    def visit_FunctionDef(self, node: Any): ...
    def visit_Return(self, node: Any) -> None: ...



from __future__ import annotations

from typing import Any, List

from typing_extensions import Literal

from ..nn import Layer

DEFAULT_CACHE_DIR: str
VAR_DEPENDENCY: str
MODULE_HUBCONF: str
HUB_DIR: Any

def list(
    repo_dir: str,
    source: Literal["github", "gitee", "local"] = ...,
    force_reload: bool = ...,
) -> List[Any]: ...  # list[Any], but list has conflicts with function name
def help(
    repo_dir: str,
    model: str,
    source: Literal["github", "gitee", "local"] = ...,
    force_reload: bool = ...,
) -> str: ...
def load(
    repo_dir: str,
    model: str,
    source: Literal["github", "gitee", "local"] = ...,
    force_reload: bool = ...,
    **kwargs: Any,
) -> Layer: ...



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.meta_optimizers.sharding.utils import *

class FP16Utils:
    def __init__(self) -> None: ...
    @staticmethod
    def is_fp16_cast_op(block: Any, op: Any, params: Any): ...
    @staticmethod
    def is_fp32_cast_op(block: Any, op: Any): ...
    @staticmethod
    def remove_cast_op(block: Any, params: Any, segment: Any, offset: Any): ...
    @staticmethod
    def prune_fp16(block: Any, shard: Any, reduced_grads_to_param: Any, ring_ids: Any) -> None: ...
    @staticmethod
    def sync_amp_check_nan_inf(block: Any, ring_ids: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

class MNIST(Dataset):
    NAME: str = ...
    URL_PREFIX: str = ...
    TEST_IMAGE_URL: Any = ...
    TEST_IMAGE_MD5: str = ...
    TEST_LABEL_URL: Any = ...
    TEST_LABEL_MD5: str = ...
    TRAIN_IMAGE_URL: Any = ...
    TRAIN_IMAGE_MD5: str = ...
    TRAIN_LABEL_URL: Any = ...
    TRAIN_LABEL_MD5: str = ...
    backend: Any = ...
    mode: Any = ...
    image_path: Any = ...
    label_path: Any = ...
    transform: Any = ...
    dtype: Any = ...
    def __init__(
        self,
        image_path: Optional[Any] = ...,
        label_path: Optional[Any] = ...,
        mode: str = ...,
        transform: Optional[Any] = ...,
        download: bool = ...,
        backend: Optional[Any] = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...

class FashionMNIST(MNIST):
    NAME: str = ...
    URL_PREFIX: str = ...
    TEST_IMAGE_URL: Any = ...
    TEST_IMAGE_MD5: str = ...
    TEST_LABEL_URL: Any = ...
    TEST_LABEL_MD5: str = ...
    TRAIN_IMAGE_URL: Any = ...
    TRAIN_IMAGE_MD5: str = ...
    TRAIN_LABEL_URL: Any = ...
    TRAIN_LABEL_MD5: str = ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL_PREFIX: str
CIFAR10_URL: Any
CIFAR10_MD5: str
CIFAR100_URL: Any
CIFAR100_MD5: str
MODE_FLAG_MAP: Any

class Cifar10(Dataset):
    mode: Any = ...
    backend: Any = ...
    data_file: Any = ...
    transform: Any = ...
    dtype: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        mode: str = ...,
        transform: Optional[Any] = ...,
        download: bool = ...,
        backend: Optional[Any] = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...

class Cifar100(Cifar10):
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        mode: str = ...,
        transform: Optional[Any] = ...,
        download: bool = ...,
        backend: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class Evaluator:
    states: Any = ...
    metrics: Any = ...
    helper: Any = ...
    def __init__(self, name: Any, **kwargs: Any) -> None: ...
    def reset(self, executor: Any, reset_program: Optional[Any] = ...) -> None: ...
    def eval(self, executor: Any, eval_program: Optional[Any] = ...) -> None: ...

class ChunkEvaluator(Evaluator):
    num_infer_chunks: Any = ...
    num_label_chunks: Any = ...
    num_correct_chunks: Any = ...
    def __init__(
        self, input: Any, label: Any, chunk_scheme: Any, num_chunk_types: Any, excluded_chunk_types: Optional[Any] = ...
    ) -> None: ...
    def eval(self, executor: Any, eval_program: Optional[Any] = ...): ...

class EditDistance(Evaluator):
    total_distance: Any = ...
    seq_num: Any = ...
    instance_error: Any = ...
    def __init__(self, input: Any, label: Any, ignored_tokens: Optional[Any] = ..., **kwargs: Any) -> None: ...
    def eval(self, executor: Any, eval_program: Optional[Any] = ...): ...

class DetectionMAP(Evaluator):
    has_state: Any = ...
    cur_map: Any = ...
    accum_map: Any = ...
    def __init__(
        self,
        input: Any,
        gt_label: Any,
        gt_box: Any,
        gt_difficult: Optional[Any] = ...,
        class_num: Optional[Any] = ...,
        background_label: int = ...,
        overlap_threshold: float = ...,
        evaluate_difficult: bool = ...,
        ap_version: str = ...,
    ) -> None: ...
    def get_map_var(self): ...
    def reset(self, executor: Any, reset_program: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any

def get_all_op_protos(): ...
def is_str(s: Any): ...

class OpDescCreationMethod:
    __op_proto__: Any = ...
    def __init__(self, op_proto: Any) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...
    @staticmethod
    def any_is_true(generator: Any): ...

class OpInfo:
    name: Any = ...
    method: Any = ...
    inputs: Any = ...
    outputs: Any = ...
    attrs: Any = ...
    def __init__(self, name: Any, method: Any, inputs: Any, outputs: Any, attrs: Any) -> None: ...

def create_op_creation_method(op_proto: Any): ...

class OperatorFactory:
    op_methods: Any = ...
    def __init__(self) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...
    def types(self): ...
    def get_op_info(self, t: Any): ...
    def get_op_input_names(self, type: Any): ...
    def get_op_inputs(self, type: Any): ...
    def get_op_output_names(self, type: Any): ...
    def get_op_outputs(self, type: Any): ...
    def get_op_attr_names(self, type: Any): ...

class __RecurrentOp__:
    __proto__: Any = ...
    type: str = ...
    def __init__(self) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...

class __DynamicRecurrentOp__:
    __proto__: Any = ...
    type: str = ...
    def __init__(self) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...

class __CondOp__:
    __proto__: Any = ...
    type: str = ...
    def __init__(self) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any): ...

Operator: Any
RecurrentOp: Any
DynamicRecurrentOp: Any
CondOp: Any
